<?php

namespace MailerLite_Woo\MailerLiteApi;

use MailerLite_Woo\Http\Client\HttpClient;
use MailerLite_Woo\MailerLiteApi\Common\ApiConstants;
use MailerLite_Woo\MailerLiteApi\Common\RestClient;
use MailerLite_Woo\MailerLiteApi\Exceptions\MailerLiteSdkException;
/**
 * Class MailerLite
 *
 * @package MailerLiteApi
 */
class MailerLite
{
    /**
     * @var null | string
     */
    protected $apiKey;
    /**
     * @var RestClient
     */
    protected $restClient;
    /**
     * @param string|null $apiKey
     * @param HttpClient $client
     */
    public function __construct($apiKey = null, \MailerLite_Woo\Http\Client\HttpClient $httpClient = null)
    {
        if (\is_null($apiKey)) {
            throw new \MailerLite_Woo\MailerLiteApi\Exceptions\MailerLiteSdkException("API key is not provided");
        }
        $this->apiKey = $apiKey;
        $this->restClient = new \MailerLite_Woo\MailerLiteApi\Common\RestClient($this->getBaseUrl(), $apiKey, $httpClient);
    }
    /**
     * @return \MailerLiteApi\Api\Groups
     */
    public function groups()
    {
        return new \MailerLite_Woo\MailerLiteApi\Api\Groups($this->restClient);
    }
    /**
     * @return \MailerLiteApi\Api\Fields
     */
    public function fields()
    {
        return new \MailerLite_Woo\MailerLiteApi\Api\Fields($this->restClient);
    }
    /**
     * @return \MailerLiteApi\Api\Subscribers
     */
    public function subscribers()
    {
        return new \MailerLite_Woo\MailerLiteApi\Api\Subscribers($this->restClient);
    }
    /**
     * @return \MailerLiteApi\Api\Campaigns
     */
    public function campaigns()
    {
        return new \MailerLite_Woo\MailerLiteApi\Api\Campaigns($this->restClient);
    }
    /**
     * @return \MailerLiteApi\Api\Stats
     */
    public function stats()
    {
        return new \MailerLite_Woo\MailerLiteApi\Api\Stats($this->restClient);
    }
    /**
     * @return \MailerLiteApi\Api\Settings
     */
    public function settings()
    {
        return new \MailerLite_Woo\MailerLiteApi\Api\Settings($this->restClient);
    }
    public function woocommerce()
    {
        return new \MailerLite_Woo\MailerLiteApi\Api\WooCommerce($this->restClient);
    }
    /**
     * @return \MailerLiteApi\Api\Segments
     */
    public function segments()
    {
        return new \MailerLite_Woo\MailerLiteApi\Api\Segments($this->restClient);
    }
    /**
     * @return \MailerLiteApi\Api\Batch
     */
    public function batch()
    {
        return new \MailerLite_Woo\MailerLiteApi\Api\Batch($this->restClient);
    }
    /**
     * @param  string $version
     * @return string
     */
    public function getBaseUrl($version = \MailerLite_Woo\MailerLiteApi\Common\ApiConstants::VERSION)
    {
        return \MailerLite_Woo\MailerLiteApi\Common\ApiConstants::BASE_URL . $version . '/';
    }
}
