<?php

declare (strict_types=1);
namespace MailerLite_Woo\PhpParser\Builder;

use MailerLite_Woo\PhpParser\Builder;
use MailerLite_Woo\PhpParser\BuilderHelpers;
use MailerLite_Woo\PhpParser\Node;
use MailerLite_Woo\PhpParser\Node\Stmt;
class TraitUse implements \MailerLite_Woo\PhpParser\Builder
{
    protected $traits = [];
    protected $adaptations = [];
    /**
     * Creates a trait use builder.
     *
     * @param Node\Name|string ...$traits Names of used traits
     */
    public function __construct(...$traits)
    {
        foreach ($traits as $trait) {
            $this->and($trait);
        }
    }
    /**
     * Adds used trait.
     *
     * @param Node\Name|string $trait Trait name
     *
     * @return $this The builder instance (for fluid interface)
     */
    public function and($trait)
    {
        $this->traits[] = \MailerLite_Woo\PhpParser\BuilderHelpers::normalizeName($trait);
        return $this;
    }
    /**
     * Adds trait adaptation.
     *
     * @param Stmt\TraitUseAdaptation|Builder\TraitUseAdaptation $adaptation Trait adaptation
     *
     * @return $this The builder instance (for fluid interface)
     */
    public function with($adaptation)
    {
        $adaptation = \MailerLite_Woo\PhpParser\BuilderHelpers::normalizeNode($adaptation);
        if (!$adaptation instanceof \MailerLite_Woo\PhpParser\Node\Stmt\TraitUseAdaptation) {
            throw new \LogicException('Adaptation must have type TraitUseAdaptation');
        }
        $this->adaptations[] = $adaptation;
        return $this;
    }
    /**
     * Returns the built node.
     *
     * @return Node The built node
     */
    public function getNode() : \MailerLite_Woo\PhpParser\Node
    {
        return new \MailerLite_Woo\PhpParser\Node\Stmt\TraitUse($this->traits, $this->adaptations);
    }
}
