<?php

declare (strict_types=1);
namespace MailerLite_Woo\PhpParser\Builder;

use MailerLite_Woo\PhpParser\Builder;
use MailerLite_Woo\PhpParser\BuilderHelpers;
use MailerLite_Woo\PhpParser\Node;
use MailerLite_Woo\PhpParser\Node\Stmt;
class Use_ implements \MailerLite_Woo\PhpParser\Builder
{
    protected $name;
    protected $type;
    protected $alias = null;
    /**
     * Creates a name use (alias) builder.
     *
     * @param Node\Name|string $name Name of the entity (namespace, class, function, constant) to alias
     * @param int              $type One of the Stmt\Use_::TYPE_* constants
     */
    public function __construct($name, int $type)
    {
        $this->name = \MailerLite_Woo\PhpParser\BuilderHelpers::normalizeName($name);
        $this->type = $type;
    }
    /**
     * Sets alias for used name.
     *
     * @param string $alias Alias to use (last component of full name by default)
     *
     * @return $this The builder instance (for fluid interface)
     */
    public function as(string $alias)
    {
        $this->alias = $alias;
        return $this;
    }
    /**
     * Returns the built node.
     *
     * @return Node The built node
     */
    public function getNode() : \MailerLite_Woo\PhpParser\Node
    {
        return new \MailerLite_Woo\PhpParser\Node\Stmt\Use_([new \MailerLite_Woo\PhpParser\Node\Stmt\UseUse($this->name, $this->alias)], $this->type);
    }
}
