<?php

declare (strict_types=1);
namespace MailerLite_Woo\PhpParser\NodeVisitor;

use function array_pop;
use function count;
use MailerLite_Woo\PhpParser\Node;
use MailerLite_Woo\PhpParser\NodeVisitorAbstract;
/**
 * Visitor that connects a child node to its parent node.
 *
 * On the child node, the parent node can be accessed through
 * <code>$node->getAttribute('parent')</code>.
 */
final class ParentConnectingVisitor extends \MailerLite_Woo\PhpParser\NodeVisitorAbstract
{
    /**
     * @var Node[]
     */
    private $stack = [];
    public function beforeTraverse(array $nodes)
    {
        $this->stack = [];
    }
    public function enterNode(\MailerLite_Woo\PhpParser\Node $node)
    {
        if (!empty($this->stack)) {
            $node->setAttribute('parent', $this->stack[\count($this->stack) - 1]);
        }
        $this->stack[] = $node;
    }
    public function leaveNode(\MailerLite_Woo\PhpParser\Node $node)
    {
        \array_pop($this->stack);
    }
}
