<?php

declare (strict_types=1);
/*
 * This file is part of PharIo\Manifest.
 *
 * (c) Arne Blankerts <arne@blankerts.de>, Sebastian Heuer <sebastian@phpeople.de>, Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\PharIo\Manifest;

class ManifestLoader
{
    public static function fromFile(string $filename) : \MailerLite_Woo\PharIo\Manifest\Manifest
    {
        try {
            return (new \MailerLite_Woo\PharIo\Manifest\ManifestDocumentMapper())->map(\MailerLite_Woo\PharIo\Manifest\ManifestDocument::fromFile($filename));
        } catch (\MailerLite_Woo\PharIo\Manifest\Exception $e) {
            throw new \MailerLite_Woo\PharIo\Manifest\ManifestLoaderException(\sprintf('Loading %s failed.', $filename), (int) $e->getCode(), $e);
        }
    }
    public static function fromPhar(string $filename) : \MailerLite_Woo\PharIo\Manifest\Manifest
    {
        return self::fromFile('phar://' . $filename . '/manifest.xml');
    }
    public static function fromString(string $manifest) : \MailerLite_Woo\PharIo\Manifest\Manifest
    {
        try {
            return (new \MailerLite_Woo\PharIo\Manifest\ManifestDocumentMapper())->map(\MailerLite_Woo\PharIo\Manifest\ManifestDocument::fromString($manifest));
        } catch (\MailerLite_Woo\PharIo\Manifest\Exception $e) {
            throw new \MailerLite_Woo\PharIo\Manifest\ManifestLoaderException('Processing string failed', (int) $e->getCode(), $e);
        }
    }
}
