<?php

declare (strict_types=1);
/*
 * This file is part of PharIo\Manifest.
 *
 * (c) Arne Blankerts <arne@blankerts.de>, Sebastian Heuer <sebastian@phpeople.de>, Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\PharIo\Manifest;

use MailerLite_Woo\PharIo\Version\Version;
use MailerLite_Woo\PharIo\Version\VersionConstraint;
class Extension extends \MailerLite_Woo\PharIo\Manifest\Type
{
    /** @var ApplicationName */
    private $application;
    /** @var VersionConstraint */
    private $versionConstraint;
    public function __construct(\MailerLite_Woo\PharIo\Manifest\ApplicationName $application, \MailerLite_Woo\PharIo\Version\VersionConstraint $versionConstraint)
    {
        $this->application = $application;
        $this->versionConstraint = $versionConstraint;
    }
    public function getApplicationName() : \MailerLite_Woo\PharIo\Manifest\ApplicationName
    {
        return $this->application;
    }
    public function getVersionConstraint() : \MailerLite_Woo\PharIo\Version\VersionConstraint
    {
        return $this->versionConstraint;
    }
    public function isExtension() : bool
    {
        return \true;
    }
    public function isExtensionFor(\MailerLite_Woo\PharIo\Manifest\ApplicationName $name) : bool
    {
        return $this->application->isEqual($name);
    }
    public function isCompatibleWith(\MailerLite_Woo\PharIo\Manifest\ApplicationName $name, \MailerLite_Woo\PharIo\Version\Version $version) : bool
    {
        return $this->isExtensionFor($name) && $this->versionConstraint->complies($version);
    }
}
