<?php

declare (strict_types=1);
/*
 * This file is part of PharIo\Manifest.
 *
 * (c) Arne Blankerts <arne@blankerts.de>, Sebastian Heuer <sebastian@phpeople.de>, Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\PharIo\Manifest;

use MailerLite_Woo\PharIo\Version\Version;
class Manifest
{
    /** @var ApplicationName */
    private $name;
    /** @var Version */
    private $version;
    /** @var Type */
    private $type;
    /** @var CopyrightInformation */
    private $copyrightInformation;
    /** @var RequirementCollection */
    private $requirements;
    /** @var BundledComponentCollection */
    private $bundledComponents;
    public function __construct(\MailerLite_Woo\PharIo\Manifest\ApplicationName $name, \MailerLite_Woo\PharIo\Version\Version $version, \MailerLite_Woo\PharIo\Manifest\Type $type, \MailerLite_Woo\PharIo\Manifest\CopyrightInformation $copyrightInformation, \MailerLite_Woo\PharIo\Manifest\RequirementCollection $requirements, \MailerLite_Woo\PharIo\Manifest\BundledComponentCollection $bundledComponents)
    {
        $this->name = $name;
        $this->version = $version;
        $this->type = $type;
        $this->copyrightInformation = $copyrightInformation;
        $this->requirements = $requirements;
        $this->bundledComponents = $bundledComponents;
    }
    public function getName() : \MailerLite_Woo\PharIo\Manifest\ApplicationName
    {
        return $this->name;
    }
    public function getVersion() : \MailerLite_Woo\PharIo\Version\Version
    {
        return $this->version;
    }
    public function getType() : \MailerLite_Woo\PharIo\Manifest\Type
    {
        return $this->type;
    }
    public function getCopyrightInformation() : \MailerLite_Woo\PharIo\Manifest\CopyrightInformation
    {
        return $this->copyrightInformation;
    }
    public function getRequirements() : \MailerLite_Woo\PharIo\Manifest\RequirementCollection
    {
        return $this->requirements;
    }
    public function getBundledComponents() : \MailerLite_Woo\PharIo\Manifest\BundledComponentCollection
    {
        return $this->bundledComponents;
    }
    public function isApplication() : bool
    {
        return $this->type->isApplication();
    }
    public function isLibrary() : bool
    {
        return $this->type->isLibrary();
    }
    public function isExtension() : bool
    {
        return $this->type->isExtension();
    }
    public function isExtensionFor(\MailerLite_Woo\PharIo\Manifest\ApplicationName $application, \MailerLite_Woo\PharIo\Version\Version $version = null) : bool
    {
        if (!$this->isExtension()) {
            return \false;
        }
        /** @var Extension $type */
        $type = $this->type;
        if ($version !== null) {
            return $type->isCompatibleWith($application, $version);
        }
        return $type->isExtensionFor($application);
    }
}
