<?php

declare (strict_types=1);
namespace MailerLite_Woo\Http\Client\Common\Plugin;

use MailerLite_Woo\Http\Client\Common\Plugin;
use MailerLite_Woo\Http\Message\Encoding\ChunkStream;
use MailerLite_Woo\Http\Promise\Promise;
use MailerLite_Woo\Psr\Http\Message\RequestInterface;
/**
 * Allow to set the correct content length header on the request or to transfer it as a chunk if not possible.
 *
 * @author Joel Wurtz <joel.wurtz@gmail.com>
 */
final class ContentLengthPlugin implements \MailerLite_Woo\Http\Client\Common\Plugin
{
    /**
     * {@inheritdoc}
     */
    public function handleRequest(\MailerLite_Woo\Psr\Http\Message\RequestInterface $request, callable $next, callable $first) : \MailerLite_Woo\Http\Promise\Promise
    {
        if (!$request->hasHeader('Content-Length')) {
            $stream = $request->getBody();
            // Cannot determine the size so we use a chunk stream
            if (null === $stream->getSize()) {
                $stream = new \MailerLite_Woo\Http\Message\Encoding\ChunkStream($stream);
                $request = $request->withBody($stream);
                $request = $request->withAddedHeader('Transfer-Encoding', 'chunked');
            } else {
                $request = $request->withHeader('Content-Length', (string) $stream->getSize());
            }
        }
        return $next($request);
    }
}
