<?php

namespace MailerLite_Woo\Http\Discovery\Strategy;

use MailerLite_Woo\GuzzleHttp\Promise\Promise;
use MailerLite_Woo\GuzzleHttp\Psr7\Request as GuzzleRequest;
use MailerLite_Woo\Http\Client\HttpAsyncClient;
use MailerLite_Woo\Http\Client\HttpClient;
use MailerLite_Woo\Http\Discovery\Exception\NotFoundException;
use MailerLite_Woo\Http\Discovery\MessageFactoryDiscovery;
use MailerLite_Woo\Http\Discovery\Psr17FactoryDiscovery;
use MailerLite_Woo\Http\Message\RequestFactory;
use MailerLite_Woo\Psr\Http\Message\RequestFactoryInterface as Psr17RequestFactory;
use MailerLite_Woo\Http\Message\MessageFactory;
use MailerLite_Woo\Http\Message\MessageFactory\GuzzleMessageFactory;
use MailerLite_Woo\Http\Message\StreamFactory;
use MailerLite_Woo\Http\Message\StreamFactory\GuzzleStreamFactory;
use MailerLite_Woo\Http\Message\UriFactory;
use MailerLite_Woo\Http\Message\UriFactory\GuzzleUriFactory;
use MailerLite_Woo\Http\Message\MessageFactory\DiactorosMessageFactory;
use MailerLite_Woo\Http\Message\StreamFactory\DiactorosStreamFactory;
use MailerLite_Woo\Http\Message\UriFactory\DiactorosUriFactory;
use MailerLite_Woo\Psr\Http\Client\ClientInterface as Psr18Client;
use MailerLite_Woo\Zend\Diactoros\Request as DiactorosRequest;
use MailerLite_Woo\Http\Message\MessageFactory\SlimMessageFactory;
use MailerLite_Woo\Http\Message\StreamFactory\SlimStreamFactory;
use MailerLite_Woo\Http\Message\UriFactory\SlimUriFactory;
use MailerLite_Woo\Slim\Http\Request as SlimRequest;
use MailerLite_Woo\GuzzleHttp\Client as GuzzleHttp;
use MailerLite_Woo\Http\Adapter\Guzzle7\Client as Guzzle7;
use MailerLite_Woo\Http\Adapter\Guzzle6\Client as Guzzle6;
use MailerLite_Woo\Http\Adapter\Guzzle5\Client as Guzzle5;
use MailerLite_Woo\Http\Client\Curl\Client as Curl;
use MailerLite_Woo\Http\Client\Socket\Client as Socket;
use MailerLite_Woo\Http\Adapter\React\Client as React;
use MailerLite_Woo\Http\Adapter\Buzz\Client as Buzz;
use MailerLite_Woo\Http\Adapter\Cake\Client as Cake;
use MailerLite_Woo\Http\Adapter\Zend\Client as Zend;
use MailerLite_Woo\Http\Adapter\Artax\Client as Artax;
use MailerLite_Woo\Symfony\Component\HttpClient\HttplugClient as SymfonyHttplug;
use MailerLite_Woo\Symfony\Component\HttpClient\Psr18Client as SymfonyPsr18;
use MailerLite_Woo\Nyholm\Psr7\Factory\HttplugFactory as NyholmHttplugFactory;
/**
 * @internal
 *
 * @author Tobias Nyholm <tobias.nyholm@gmail.com>
 */
final class CommonClassesStrategy implements \MailerLite_Woo\Http\Discovery\Strategy\DiscoveryStrategy
{
    /**
     * @var array
     */
    private static $classes = [\MailerLite_Woo\Http\Message\MessageFactory::class => [['class' => \MailerLite_Woo\Nyholm\Psr7\Factory\HttplugFactory::class, 'condition' => [\MailerLite_Woo\Nyholm\Psr7\Factory\HttplugFactory::class]], ['class' => \MailerLite_Woo\Http\Message\MessageFactory\GuzzleMessageFactory::class, 'condition' => [\MailerLite_Woo\GuzzleHttp\Psr7\Request::class, \MailerLite_Woo\Http\Message\MessageFactory\GuzzleMessageFactory::class]], ['class' => \MailerLite_Woo\Http\Message\MessageFactory\DiactorosMessageFactory::class, 'condition' => [\MailerLite_Woo\Zend\Diactoros\Request::class, \MailerLite_Woo\Http\Message\MessageFactory\DiactorosMessageFactory::class]], ['class' => \MailerLite_Woo\Http\Message\MessageFactory\SlimMessageFactory::class, 'condition' => [\MailerLite_Woo\Slim\Http\Request::class, \MailerLite_Woo\Http\Message\MessageFactory\SlimMessageFactory::class]]], \MailerLite_Woo\Http\Message\StreamFactory::class => [['class' => \MailerLite_Woo\Nyholm\Psr7\Factory\HttplugFactory::class, 'condition' => [\MailerLite_Woo\Nyholm\Psr7\Factory\HttplugFactory::class]], ['class' => \MailerLite_Woo\Http\Message\StreamFactory\GuzzleStreamFactory::class, 'condition' => [\MailerLite_Woo\GuzzleHttp\Psr7\Request::class, \MailerLite_Woo\Http\Message\StreamFactory\GuzzleStreamFactory::class]], ['class' => \MailerLite_Woo\Http\Message\StreamFactory\DiactorosStreamFactory::class, 'condition' => [\MailerLite_Woo\Zend\Diactoros\Request::class, \MailerLite_Woo\Http\Message\StreamFactory\DiactorosStreamFactory::class]], ['class' => \MailerLite_Woo\Http\Message\StreamFactory\SlimStreamFactory::class, 'condition' => [\MailerLite_Woo\Slim\Http\Request::class, \MailerLite_Woo\Http\Message\StreamFactory\SlimStreamFactory::class]]], \MailerLite_Woo\Http\Message\UriFactory::class => [['class' => \MailerLite_Woo\Nyholm\Psr7\Factory\HttplugFactory::class, 'condition' => [\MailerLite_Woo\Nyholm\Psr7\Factory\HttplugFactory::class]], ['class' => \MailerLite_Woo\Http\Message\UriFactory\GuzzleUriFactory::class, 'condition' => [\MailerLite_Woo\GuzzleHttp\Psr7\Request::class, \MailerLite_Woo\Http\Message\UriFactory\GuzzleUriFactory::class]], ['class' => \MailerLite_Woo\Http\Message\UriFactory\DiactorosUriFactory::class, 'condition' => [\MailerLite_Woo\Zend\Diactoros\Request::class, \MailerLite_Woo\Http\Message\UriFactory\DiactorosUriFactory::class]], ['class' => \MailerLite_Woo\Http\Message\UriFactory\SlimUriFactory::class, 'condition' => [\MailerLite_Woo\Slim\Http\Request::class, \MailerLite_Woo\Http\Message\UriFactory\SlimUriFactory::class]]], \MailerLite_Woo\Http\Client\HttpAsyncClient::class => [['class' => \MailerLite_Woo\Symfony\Component\HttpClient\HttplugClient::class, 'condition' => [\MailerLite_Woo\Symfony\Component\HttpClient\HttplugClient::class, \MailerLite_Woo\GuzzleHttp\Promise\Promise::class, \MailerLite_Woo\Http\Message\RequestFactory::class, [self::class, 'isPsr17FactoryInstalled']]], ['class' => \MailerLite_Woo\Http\Adapter\Guzzle7\Client::class, 'condition' => \MailerLite_Woo\Http\Adapter\Guzzle7\Client::class], ['class' => \MailerLite_Woo\Http\Adapter\Guzzle6\Client::class, 'condition' => \MailerLite_Woo\Http\Adapter\Guzzle6\Client::class], ['class' => \MailerLite_Woo\Http\Client\Curl\Client::class, 'condition' => \MailerLite_Woo\Http\Client\Curl\Client::class], ['class' => \MailerLite_Woo\Http\Adapter\React\Client::class, 'condition' => \MailerLite_Woo\Http\Adapter\React\Client::class]], \MailerLite_Woo\Http\Client\HttpClient::class => [['class' => \MailerLite_Woo\Symfony\Component\HttpClient\HttplugClient::class, 'condition' => [\MailerLite_Woo\Symfony\Component\HttpClient\HttplugClient::class, \MailerLite_Woo\Http\Message\RequestFactory::class, [self::class, 'isPsr17FactoryInstalled']]], ['class' => \MailerLite_Woo\Http\Adapter\Guzzle7\Client::class, 'condition' => \MailerLite_Woo\Http\Adapter\Guzzle7\Client::class], ['class' => \MailerLite_Woo\Http\Adapter\Guzzle6\Client::class, 'condition' => \MailerLite_Woo\Http\Adapter\Guzzle6\Client::class], ['class' => \MailerLite_Woo\Http\Adapter\Guzzle5\Client::class, 'condition' => \MailerLite_Woo\Http\Adapter\Guzzle5\Client::class], ['class' => \MailerLite_Woo\Http\Client\Curl\Client::class, 'condition' => \MailerLite_Woo\Http\Client\Curl\Client::class], ['class' => \MailerLite_Woo\Http\Client\Socket\Client::class, 'condition' => \MailerLite_Woo\Http\Client\Socket\Client::class], ['class' => \MailerLite_Woo\Http\Adapter\Buzz\Client::class, 'condition' => \MailerLite_Woo\Http\Adapter\Buzz\Client::class], ['class' => \MailerLite_Woo\Http\Adapter\React\Client::class, 'condition' => \MailerLite_Woo\Http\Adapter\React\Client::class], ['class' => \MailerLite_Woo\Http\Adapter\Cake\Client::class, 'condition' => \MailerLite_Woo\Http\Adapter\Cake\Client::class], ['class' => \MailerLite_Woo\Http\Adapter\Zend\Client::class, 'condition' => \MailerLite_Woo\Http\Adapter\Zend\Client::class], ['class' => \MailerLite_Woo\Http\Adapter\Artax\Client::class, 'condition' => \MailerLite_Woo\Http\Adapter\Artax\Client::class], ['class' => [self::class, 'buzzInstantiate'], 'condition' => [\MailerLite_Woo\Buzz\Client\FileGetContents::class, \MailerLite_Woo\Buzz\Message\ResponseBuilder::class]]], \MailerLite_Woo\Psr\Http\Client\ClientInterface::class => [['class' => [self::class, 'symfonyPsr18Instantiate'], 'condition' => [\MailerLite_Woo\Symfony\Component\HttpClient\Psr18Client::class, \MailerLite_Woo\Psr\Http\Message\RequestFactoryInterface::class]], ['class' => \MailerLite_Woo\GuzzleHttp\Client::class, 'condition' => [self::class, 'isGuzzleImplementingPsr18']], ['class' => [self::class, 'buzzInstantiate'], 'condition' => [\MailerLite_Woo\Buzz\Client\FileGetContents::class, \MailerLite_Woo\Buzz\Message\ResponseBuilder::class]]]];
    /**
     * {@inheritdoc}
     */
    public static function getCandidates($type)
    {
        if (\MailerLite_Woo\Psr\Http\Client\ClientInterface::class === $type) {
            return self::getPsr18Candidates();
        }
        return self::$classes[$type] ?? [];
    }
    /**
     * @return array The return value is always an array with zero or more elements. Each
     *               element is an array with two keys ['class' => string, 'condition' => mixed].
     */
    private static function getPsr18Candidates()
    {
        $candidates = self::$classes[\MailerLite_Woo\Psr\Http\Client\ClientInterface::class];
        // HTTPlug 2.0 clients implements PSR18Client too.
        foreach (self::$classes[\MailerLite_Woo\Http\Client\HttpClient::class] as $c) {
            try {
                if (\is_subclass_of($c['class'], \MailerLite_Woo\Psr\Http\Client\ClientInterface::class)) {
                    $candidates[] = $c;
                }
            } catch (\Throwable $e) {
                \trigger_error(\sprintf('Got exception "%s (%s)" while checking if a PSR-18 Client is available', \get_class($e), $e->getMessage()), \E_USER_WARNING);
            }
        }
        return $candidates;
    }
    public static function buzzInstantiate()
    {
        return new \MailerLite_Woo\Buzz\Client\FileGetContents(\MailerLite_Woo\Http\Discovery\MessageFactoryDiscovery::find());
    }
    public static function symfonyPsr18Instantiate()
    {
        return new \MailerLite_Woo\Symfony\Component\HttpClient\Psr18Client(null, \MailerLite_Woo\Http\Discovery\Psr17FactoryDiscovery::findResponseFactory(), \MailerLite_Woo\Http\Discovery\Psr17FactoryDiscovery::findStreamFactory());
    }
    public static function isGuzzleImplementingPsr18()
    {
        return \defined('GuzzleHttp\\ClientInterface::MAJOR_VERSION');
    }
    /**
     * Can be used as a condition.
     *
     * @return bool
     */
    public static function isPsr17FactoryInstalled()
    {
        try {
            \MailerLite_Woo\Http\Discovery\Psr17FactoryDiscovery::findResponseFactory();
        } catch (\MailerLite_Woo\Http\Discovery\Exception\NotFoundException $e) {
            return \false;
        } catch (\Throwable $e) {
            \trigger_error(\sprintf('Got exception "%s (%s)" while checking if a PSR-17 ResponseFactory is available', \get_class($e), $e->getMessage()), \E_USER_WARNING);
            return \false;
        }
        return \true;
    }
}
