<?php

namespace MailerLite_Woo\Http\Discovery\Strategy;

use MailerLite_Woo\Psr\Http\Message\RequestFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\ResponseFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\ServerRequestFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\StreamFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\UploadedFileFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\UriFactoryInterface;
/**
 * @internal
 *
 * @author Tobias Nyholm <tobias.nyholm@gmail.com>
 */
final class CommonPsr17ClassesStrategy implements \MailerLite_Woo\Http\Discovery\Strategy\DiscoveryStrategy
{
    /**
     * @var array
     */
    private static $classes = [\MailerLite_Woo\Psr\Http\Message\RequestFactoryInterface::class => ['MailerLite_Woo\\Phalcon\\Http\\Message\\RequestFactory', 'MailerLite_Woo\\Nyholm\\Psr7\\Factory\\Psr17Factory', 'MailerLite_Woo\\Zend\\Diactoros\\RequestFactory', 'MailerLite_Woo\\GuzzleHttp\\Psr7\\HttpFactory', 'MailerLite_Woo\\Http\\Factory\\Diactoros\\RequestFactory', 'MailerLite_Woo\\Http\\Factory\\Guzzle\\RequestFactory', 'MailerLite_Woo\\Http\\Factory\\Slim\\RequestFactory', 'MailerLite_Woo\\Laminas\\Diactoros\\RequestFactory', 'MailerLite_Woo\\Slim\\Psr7\\Factory\\RequestFactory'], \MailerLite_Woo\Psr\Http\Message\ResponseFactoryInterface::class => ['MailerLite_Woo\\Phalcon\\Http\\Message\\ResponseFactory', 'MailerLite_Woo\\Nyholm\\Psr7\\Factory\\Psr17Factory', 'MailerLite_Woo\\Zend\\Diactoros\\ResponseFactory', 'MailerLite_Woo\\GuzzleHttp\\Psr7\\HttpFactory', 'MailerLite_Woo\\Http\\Factory\\Diactoros\\ResponseFactory', 'MailerLite_Woo\\Http\\Factory\\Guzzle\\ResponseFactory', 'MailerLite_Woo\\Http\\Factory\\Slim\\ResponseFactory', 'MailerLite_Woo\\Laminas\\Diactoros\\ResponseFactory', 'MailerLite_Woo\\Slim\\Psr7\\Factory\\ResponseFactory'], \MailerLite_Woo\Psr\Http\Message\ServerRequestFactoryInterface::class => ['MailerLite_Woo\\Phalcon\\Http\\Message\\ServerRequestFactory', 'MailerLite_Woo\\Nyholm\\Psr7\\Factory\\Psr17Factory', 'MailerLite_Woo\\Zend\\Diactoros\\ServerRequestFactory', 'MailerLite_Woo\\GuzzleHttp\\Psr7\\HttpFactory', 'MailerLite_Woo\\Http\\Factory\\Diactoros\\ServerRequestFactory', 'MailerLite_Woo\\Http\\Factory\\Guzzle\\ServerRequestFactory', 'MailerLite_Woo\\Http\\Factory\\Slim\\ServerRequestFactory', 'MailerLite_Woo\\Laminas\\Diactoros\\ServerRequestFactory', 'MailerLite_Woo\\Slim\\Psr7\\Factory\\ServerRequestFactory'], \MailerLite_Woo\Psr\Http\Message\StreamFactoryInterface::class => ['MailerLite_Woo\\Phalcon\\Http\\Message\\StreamFactory', 'MailerLite_Woo\\Nyholm\\Psr7\\Factory\\Psr17Factory', 'MailerLite_Woo\\Zend\\Diactoros\\StreamFactory', 'MailerLite_Woo\\GuzzleHttp\\Psr7\\HttpFactory', 'MailerLite_Woo\\Http\\Factory\\Diactoros\\StreamFactory', 'MailerLite_Woo\\Http\\Factory\\Guzzle\\StreamFactory', 'MailerLite_Woo\\Http\\Factory\\Slim\\StreamFactory', 'MailerLite_Woo\\Laminas\\Diactoros\\StreamFactory', 'MailerLite_Woo\\Slim\\Psr7\\Factory\\StreamFactory'], \MailerLite_Woo\Psr\Http\Message\UploadedFileFactoryInterface::class => ['MailerLite_Woo\\Phalcon\\Http\\Message\\UploadedFileFactory', 'MailerLite_Woo\\Nyholm\\Psr7\\Factory\\Psr17Factory', 'MailerLite_Woo\\Zend\\Diactoros\\UploadedFileFactory', 'MailerLite_Woo\\GuzzleHttp\\Psr7\\HttpFactory', 'MailerLite_Woo\\Http\\Factory\\Diactoros\\UploadedFileFactory', 'MailerLite_Woo\\Http\\Factory\\Guzzle\\UploadedFileFactory', 'MailerLite_Woo\\Http\\Factory\\Slim\\UploadedFileFactory', 'MailerLite_Woo\\Laminas\\Diactoros\\UploadedFileFactory', 'MailerLite_Woo\\Slim\\Psr7\\Factory\\UploadedFileFactory'], \MailerLite_Woo\Psr\Http\Message\UriFactoryInterface::class => ['MailerLite_Woo\\Phalcon\\Http\\Message\\UriFactory', 'MailerLite_Woo\\Nyholm\\Psr7\\Factory\\Psr17Factory', 'MailerLite_Woo\\Zend\\Diactoros\\UriFactory', 'MailerLite_Woo\\GuzzleHttp\\Psr7\\HttpFactory', 'MailerLite_Woo\\Http\\Factory\\Diactoros\\UriFactory', 'MailerLite_Woo\\Http\\Factory\\Guzzle\\UriFactory', 'MailerLite_Woo\\Http\\Factory\\Slim\\UriFactory', 'MailerLite_Woo\\Laminas\\Diactoros\\UriFactory', 'MailerLite_Woo\\Slim\\Psr7\\Factory\\UriFactory']];
    /**
     * {@inheritdoc}
     */
    public static function getCandidates($type)
    {
        $candidates = [];
        if (isset(self::$classes[$type])) {
            foreach (self::$classes[$type] as $class) {
                $candidates[] = ['class' => $class, 'condition' => [$class]];
            }
        }
        return $candidates;
    }
}
