<?php

declare (strict_types=1);
namespace MailerLite_Woo\Http\Adapter\Guzzle7;

use MailerLite_Woo\GuzzleHttp\Exception as GuzzleExceptions;
use MailerLite_Woo\GuzzleHttp\Promise\PromiseInterface;
use MailerLite_Woo\Http\Adapter\Guzzle7\Exception\UnexpectedValueException;
use MailerLite_Woo\Http\Client\Exception as HttplugException;
use MailerLite_Woo\Http\Promise\Promise as HttpPromise;
use MailerLite_Woo\Psr\Http\Message\RequestInterface;
use MailerLite_Woo\Psr\Http\Message\ResponseInterface;
/**
 * Wrapper around Guzzle promises.
 *
 * @author Joel Wurtz <joel.wurtz@gmail.com>
 */
final class Promise implements \MailerLite_Woo\Http\Promise\Promise
{
    /**
     * @var PromiseInterface
     */
    private $promise;
    /**
     * @var string State of the promise
     */
    private $state;
    /**
     * @var ResponseInterface
     */
    private $response;
    /**
     * @var HttplugException
     */
    private $exception;
    /**
     * @var RequestInterface
     */
    private $request;
    public function __construct(\MailerLite_Woo\GuzzleHttp\Promise\PromiseInterface $promise, \MailerLite_Woo\Psr\Http\Message\RequestInterface $request)
    {
        $this->request = $request;
        $this->state = self::PENDING;
        $this->promise = $promise->then(function ($response) {
            $this->response = $response;
            $this->state = self::FULFILLED;
            return $response;
        }, function ($reason) use($request) {
            $this->state = self::REJECTED;
            if ($reason instanceof \MailerLite_Woo\Http\Client\Exception) {
                $this->exception = $reason;
            } elseif ($reason instanceof \MailerLite_Woo\GuzzleHttp\Exception\GuzzleException) {
                $this->exception = $this->handleException($reason, $request);
            } elseif ($reason instanceof \Throwable) {
                $this->exception = new \MailerLite_Woo\Http\Client\Exception\TransferException('Invalid exception returned from Guzzle7', 0, $reason);
            } else {
                $this->exception = new \MailerLite_Woo\Http\Adapter\Guzzle7\Exception\UnexpectedValueException('Reason returned from Guzzle7 must be an Exception');
            }
            throw $this->exception;
        });
    }
    /**
     * {@inheritdoc}
     */
    public function then(callable $onFulfilled = null, callable $onRejected = null)
    {
        return new static($this->promise->then($onFulfilled, $onRejected), $this->request);
    }
    /**
     * {@inheritdoc}
     */
    public function getState()
    {
        return $this->state;
    }
    /**
     * {@inheritdoc}
     */
    public function wait($unwrap = \true)
    {
        $this->promise->wait(\false);
        if ($unwrap) {
            if (self::REJECTED == $this->getState()) {
                throw $this->exception;
            }
            return $this->response;
        }
    }
    /**
     * Converts a Guzzle exception into an Httplug exception.
     *
     * @return HttplugException
     */
    private function handleException(\MailerLite_Woo\GuzzleHttp\Exception\GuzzleException $exception, \MailerLite_Woo\Psr\Http\Message\RequestInterface $request)
    {
        if ($exception instanceof \MailerLite_Woo\GuzzleHttp\Exception\ConnectException) {
            return new \MailerLite_Woo\Http\Client\Exception\NetworkException($exception->getMessage(), $exception->getRequest(), $exception);
        }
        if ($exception instanceof \MailerLite_Woo\GuzzleHttp\Exception\RequestException) {
            // Make sure we have a response for the HttpException
            if ($exception->hasResponse()) {
                return new \MailerLite_Woo\Http\Client\Exception\HttpException($exception->getMessage(), $exception->getRequest(), $exception->getResponse(), $exception);
            }
            return new \MailerLite_Woo\Http\Client\Exception\RequestException($exception->getMessage(), $exception->getRequest(), $exception);
        }
        return new \MailerLite_Woo\Http\Client\Exception\TransferException($exception->getMessage(), 0, $exception);
    }
}
