<?php

declare (strict_types=1);
/**
 * This file is part of phpDocumentor.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 *
 * @link      http://phpdoc.org
 */
namespace MailerLite_Woo\phpDocumentor\Reflection\DocBlock\Tags;

use MailerLite_Woo\phpDocumentor\Reflection\DocBlock\Description;
use MailerLite_Woo\phpDocumentor\Reflection\DocBlock\DescriptionFactory;
use MailerLite_Woo\phpDocumentor\Reflection\Type;
use MailerLite_Woo\phpDocumentor\Reflection\TypeResolver;
use MailerLite_Woo\phpDocumentor\Reflection\Types\Context as TypeContext;
use MailerLite_Woo\Webmozart\Assert\Assert;
/**
 * Reflection class for a {@}throws tag in a Docblock.
 */
final class Throws extends \MailerLite_Woo\phpDocumentor\Reflection\DocBlock\Tags\TagWithType implements \MailerLite_Woo\phpDocumentor\Reflection\DocBlock\Tags\Factory\StaticMethod
{
    public function __construct(\MailerLite_Woo\phpDocumentor\Reflection\Type $type, ?\MailerLite_Woo\phpDocumentor\Reflection\DocBlock\Description $description = null)
    {
        $this->name = 'throws';
        $this->type = $type;
        $this->description = $description;
    }
    public static function create(string $body, ?\MailerLite_Woo\phpDocumentor\Reflection\TypeResolver $typeResolver = null, ?\MailerLite_Woo\phpDocumentor\Reflection\DocBlock\DescriptionFactory $descriptionFactory = null, ?\MailerLite_Woo\phpDocumentor\Reflection\Types\Context $context = null) : self
    {
        \MailerLite_Woo\Webmozart\Assert\Assert::notNull($typeResolver);
        \MailerLite_Woo\Webmozart\Assert\Assert::notNull($descriptionFactory);
        [$type, $description] = self::extractTypeFromBody($body);
        $type = $typeResolver->resolve($type, $context);
        $description = $descriptionFactory->create($description, $context);
        return new static($type, $description);
    }
    public function __toString() : string
    {
        if ($this->description) {
            $description = $this->description->render();
        } else {
            $description = '';
        }
        $type = (string) $this->type;
        return $type . ($description !== '' ? ($type !== '' ? ' ' : '') . $description : '');
    }
}
