<?php

declare (strict_types=1);
/**
 * This file is part of phpDocumentor.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 *
 * @link http://phpdoc.org
 */
namespace MailerLite_Woo\phpDocumentor\Reflection\DocBlock\Tags;

use MailerLite_Woo\phpDocumentor\Reflection\DocBlock\Description;
use MailerLite_Woo\phpDocumentor\Reflection\DocBlock\DescriptionFactory;
use MailerLite_Woo\phpDocumentor\Reflection\Fqsen;
use MailerLite_Woo\phpDocumentor\Reflection\FqsenResolver;
use MailerLite_Woo\phpDocumentor\Reflection\Types\Context as TypeContext;
use MailerLite_Woo\phpDocumentor\Reflection\Utils;
use MailerLite_Woo\Webmozart\Assert\Assert;
use function array_key_exists;
use function explode;
/**
 * Reflection class for a {@}uses tag in a Docblock.
 */
final class Uses extends \MailerLite_Woo\phpDocumentor\Reflection\DocBlock\Tags\BaseTag implements \MailerLite_Woo\phpDocumentor\Reflection\DocBlock\Tags\Factory\StaticMethod
{
    /** @var string */
    protected $name = 'uses';
    /** @var Fqsen */
    protected $refers;
    /**
     * Initializes this tag.
     */
    public function __construct(\MailerLite_Woo\phpDocumentor\Reflection\Fqsen $refers, ?\MailerLite_Woo\phpDocumentor\Reflection\DocBlock\Description $description = null)
    {
        $this->refers = $refers;
        $this->description = $description;
    }
    public static function create(string $body, ?\MailerLite_Woo\phpDocumentor\Reflection\FqsenResolver $resolver = null, ?\MailerLite_Woo\phpDocumentor\Reflection\DocBlock\DescriptionFactory $descriptionFactory = null, ?\MailerLite_Woo\phpDocumentor\Reflection\Types\Context $context = null) : self
    {
        \MailerLite_Woo\Webmozart\Assert\Assert::notNull($resolver);
        \MailerLite_Woo\Webmozart\Assert\Assert::notNull($descriptionFactory);
        $parts = \MailerLite_Woo\phpDocumentor\Reflection\Utils::pregSplit('/\\s+/Su', $body, 2);
        return new static(self::resolveFqsen($parts[0], $resolver, $context), $descriptionFactory->create($parts[1] ?? '', $context));
    }
    private static function resolveFqsen(string $parts, ?\MailerLite_Woo\phpDocumentor\Reflection\FqsenResolver $fqsenResolver, ?\MailerLite_Woo\phpDocumentor\Reflection\Types\Context $context) : \MailerLite_Woo\phpDocumentor\Reflection\Fqsen
    {
        \MailerLite_Woo\Webmozart\Assert\Assert::notNull($fqsenResolver);
        $fqsenParts = \explode('::', $parts);
        $resolved = $fqsenResolver->resolve($fqsenParts[0], $context);
        if (!\array_key_exists(1, $fqsenParts)) {
            return $resolved;
        }
        return new \MailerLite_Woo\phpDocumentor\Reflection\Fqsen($resolved . '::' . $fqsenParts[1]);
    }
    /**
     * Returns the structural element this tag refers to.
     */
    public function getReference() : \MailerLite_Woo\phpDocumentor\Reflection\Fqsen
    {
        return $this->refers;
    }
    /**
     * Returns a string representation of this tag.
     */
    public function __toString() : string
    {
        if ($this->description) {
            $description = $this->description->render();
        } else {
            $description = '';
        }
        $refers = (string) $this->refers;
        return $refers . ($description !== '' ? ($refers !== '' ? ' ' : '') . $description : '');
    }
}
