<?php

/*
 * This file is part of the Prophecy.
 * (c) Konstantin Kudryashov <ever.zet@gmail.com>
 *     Marcello Duarte <marcello.duarte@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\Prophecy\Prediction;

use MailerLite_Woo\Prophecy\Call\Call;
use MailerLite_Woo\Prophecy\Prophecy\ObjectProphecy;
use MailerLite_Woo\Prophecy\Prophecy\MethodProphecy;
use MailerLite_Woo\Prophecy\Util\StringUtil;
use MailerLite_Woo\Prophecy\Exception\Prediction\UnexpectedCallsException;
/**
 * No calls prediction.
 *
 * @author Konstantin Kudryashov <ever.zet@gmail.com>
 */
class NoCallsPrediction implements \MailerLite_Woo\Prophecy\Prediction\PredictionInterface
{
    private $util;
    /**
     * Initializes prediction.
     *
     * @param null|StringUtil $util
     */
    public function __construct(\MailerLite_Woo\Prophecy\Util\StringUtil $util = null)
    {
        $this->util = $util ?: new \MailerLite_Woo\Prophecy\Util\StringUtil();
    }
    /**
     * Tests that there were no calls made.
     *
     * @param Call[]         $calls
     * @param ObjectProphecy $object
     * @param MethodProphecy $method
     *
     * @throws \Prophecy\Exception\Prediction\UnexpectedCallsException
     */
    public function check(array $calls, \MailerLite_Woo\Prophecy\Prophecy\ObjectProphecy $object, \MailerLite_Woo\Prophecy\Prophecy\MethodProphecy $method)
    {
        if (!\count($calls)) {
            return;
        }
        $verb = \count($calls) === 1 ? 'was' : 'were';
        throw new \MailerLite_Woo\Prophecy\Exception\Prediction\UnexpectedCallsException(\sprintf("No calls expected that match:\n" . "  %s->%s(%s)\n" . "but %d %s made:\n%s", \get_class($object->reveal()), $method->getMethodName(), $method->getArgumentsWildcard(), \count($calls), $verb, $this->util->stringifyCalls($calls)), $method, $calls);
    }
}
