<?php

declare (strict_types=1);
/*
 * This file is part of phpunit/php-code-coverage.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\SebastianBergmann\CodeCoverage\Driver;

use function extension_loaded;
use function phpversion;
use MailerLite_Woo\SebastianBergmann\CodeCoverage\Filter;
use MailerLite_Woo\SebastianBergmann\CodeCoverage\RawCodeCoverageData;
/**
 * @internal This class is not covered by the backward compatibility promise for phpunit/php-code-coverage
 */
final class PcovDriver extends \MailerLite_Woo\SebastianBergmann\CodeCoverage\Driver\Driver
{
    /**
     * @var Filter
     */
    private $filter;
    /**
     * @throws PcovNotAvailableException
     */
    public function __construct(\MailerLite_Woo\SebastianBergmann\CodeCoverage\Filter $filter)
    {
        if (!\extension_loaded('pcov')) {
            throw new \MailerLite_Woo\SebastianBergmann\CodeCoverage\Driver\PcovNotAvailableException();
        }
        $this->filter = $filter;
    }
    public function start() : void
    {
        \pcov\start();
    }
    public function stop() : \MailerLite_Woo\SebastianBergmann\CodeCoverage\RawCodeCoverageData
    {
        \pcov\stop();
        $collect = \pcov\collect(\pcov\inclusive, !$this->filter->isEmpty() ? $this->filter->files() : \pcov\waiting());
        \pcov\clear();
        return \MailerLite_Woo\SebastianBergmann\CodeCoverage\RawCodeCoverageData::fromXdebugWithoutPathCoverage($collect);
    }
    public function nameAndVersion() : string
    {
        return 'PCOV ' . \phpversion('pcov');
    }
}
