<?php

declare (strict_types=1);
/*
 * This file is part of phpunit/php-code-coverage.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\SebastianBergmann\CodeCoverage\Driver;

use function phpversion;
use function version_compare;
use MailerLite_Woo\SebastianBergmann\CodeCoverage\Filter;
use MailerLite_Woo\SebastianBergmann\CodeCoverage\NoCodeCoverageDriverAvailableException;
use MailerLite_Woo\SebastianBergmann\CodeCoverage\NoCodeCoverageDriverWithPathCoverageSupportAvailableException;
use MailerLite_Woo\SebastianBergmann\Environment\Runtime;
final class Selector
{
    /**
     * @throws NoCodeCoverageDriverAvailableException
     * @throws PcovNotAvailableException
     * @throws PhpdbgNotAvailableException
     * @throws XdebugNotAvailableException
     * @throws Xdebug2NotEnabledException
     * @throws Xdebug3NotEnabledException
     */
    public function forLineCoverage(\MailerLite_Woo\SebastianBergmann\CodeCoverage\Filter $filter) : \MailerLite_Woo\SebastianBergmann\CodeCoverage\Driver\Driver
    {
        $runtime = new \MailerLite_Woo\SebastianBergmann\Environment\Runtime();
        if ($runtime->hasPHPDBGCodeCoverage()) {
            return new \MailerLite_Woo\SebastianBergmann\CodeCoverage\Driver\PhpdbgDriver();
        }
        if ($runtime->hasPCOV()) {
            return new \MailerLite_Woo\SebastianBergmann\CodeCoverage\Driver\PcovDriver($filter);
        }
        if ($runtime->hasXdebug()) {
            if (\version_compare(\phpversion('xdebug'), '3', '>=')) {
                $driver = new \MailerLite_Woo\SebastianBergmann\CodeCoverage\Driver\Xdebug3Driver($filter);
            } else {
                $driver = new \MailerLite_Woo\SebastianBergmann\CodeCoverage\Driver\Xdebug2Driver($filter);
            }
            $driver->enableDeadCodeDetection();
            return $driver;
        }
        throw new \MailerLite_Woo\SebastianBergmann\CodeCoverage\NoCodeCoverageDriverAvailableException();
    }
    /**
     * @throws NoCodeCoverageDriverWithPathCoverageSupportAvailableException
     * @throws XdebugNotAvailableException
     * @throws Xdebug2NotEnabledException
     * @throws Xdebug3NotEnabledException
     */
    public function forLineAndPathCoverage(\MailerLite_Woo\SebastianBergmann\CodeCoverage\Filter $filter) : \MailerLite_Woo\SebastianBergmann\CodeCoverage\Driver\Driver
    {
        if ((new \MailerLite_Woo\SebastianBergmann\Environment\Runtime())->hasXdebug()) {
            if (\version_compare(\phpversion('xdebug'), '3', '>=')) {
                $driver = new \MailerLite_Woo\SebastianBergmann\CodeCoverage\Driver\Xdebug3Driver($filter);
            } else {
                $driver = new \MailerLite_Woo\SebastianBergmann\CodeCoverage\Driver\Xdebug2Driver($filter);
            }
            $driver->enableDeadCodeDetection();
            $driver->enableBranchAndPathCoverage();
            return $driver;
        }
        throw new \MailerLite_Woo\SebastianBergmann\CodeCoverage\NoCodeCoverageDriverWithPathCoverageSupportAvailableException();
    }
}
