<?php

declare (strict_types=1);
/*
 * This file is part of phpunit/php-code-coverage.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\SebastianBergmann\CodeCoverage\StaticAnalysis;

use function array_unique;
use function sort;
use MailerLite_Woo\PhpParser\Node;
use MailerLite_Woo\PhpParser\Node\Stmt\Break_;
use MailerLite_Woo\PhpParser\Node\Stmt\Case_;
use MailerLite_Woo\PhpParser\Node\Stmt\Catch_;
use MailerLite_Woo\PhpParser\Node\Stmt\Continue_;
use MailerLite_Woo\PhpParser\Node\Stmt\Do_;
use MailerLite_Woo\PhpParser\Node\Stmt\Echo_;
use MailerLite_Woo\PhpParser\Node\Stmt\Else_;
use MailerLite_Woo\PhpParser\Node\Stmt\ElseIf_;
use MailerLite_Woo\PhpParser\Node\Stmt\Expression;
use MailerLite_Woo\PhpParser\Node\Stmt\Finally_;
use MailerLite_Woo\PhpParser\Node\Stmt\For_;
use MailerLite_Woo\PhpParser\Node\Stmt\Foreach_;
use MailerLite_Woo\PhpParser\Node\Stmt\Goto_;
use MailerLite_Woo\PhpParser\Node\Stmt\If_;
use MailerLite_Woo\PhpParser\Node\Stmt\Return_;
use MailerLite_Woo\PhpParser\Node\Stmt\Switch_;
use MailerLite_Woo\PhpParser\Node\Stmt\Throw_;
use MailerLite_Woo\PhpParser\Node\Stmt\TryCatch;
use MailerLite_Woo\PhpParser\Node\Stmt\Unset_;
use MailerLite_Woo\PhpParser\Node\Stmt\While_;
use MailerLite_Woo\PhpParser\NodeVisitorAbstract;
/**
 * @internal This class is not covered by the backward compatibility promise for phpunit/php-code-coverage
 */
final class ExecutableLinesFindingVisitor extends \MailerLite_Woo\PhpParser\NodeVisitorAbstract
{
    /**
     * @psalm-var list<int>
     */
    private $executableLines = [];
    public function enterNode(\MailerLite_Woo\PhpParser\Node $node) : void
    {
        if (!$this->isExecutable($node)) {
            return;
        }
        $this->executableLines[] = $node->getStartLine();
    }
    /**
     * @psalm-return list<int>
     */
    public function executableLines() : array
    {
        $executableLines = \array_unique($this->executableLines);
        \sort($executableLines);
        return $executableLines;
    }
    private function isExecutable(\MailerLite_Woo\PhpParser\Node $node) : bool
    {
        return $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Break_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Case_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Catch_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Continue_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Do_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Echo_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\ElseIf_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Else_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Expression || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Finally_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Foreach_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\For_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Goto_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\If_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Return_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Switch_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Throw_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\TryCatch || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\Unset_ || $node instanceof \MailerLite_Woo\PhpParser\Node\Stmt\While_;
    }
}
