<?php

declare (strict_types=1);
/*
 * This file is part of phpunit/php-code-coverage.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\SebastianBergmann\CodeCoverage\StaticAnalysis;

use MailerLite_Woo\PhpParser\Error;
use MailerLite_Woo\PhpParser\Lexer;
use MailerLite_Woo\PhpParser\NodeTraverser;
use MailerLite_Woo\PhpParser\ParserFactory;
/**
 * @internal This class is not covered by the backward compatibility promise for phpunit/php-code-coverage
 */
final class ParsingUncoveredFileAnalyser implements \MailerLite_Woo\SebastianBergmann\CodeCoverage\StaticAnalysis\UncoveredFileAnalyser
{
    public function executableLinesIn(string $filename) : array
    {
        $parser = (new \MailerLite_Woo\PhpParser\ParserFactory())->create(\MailerLite_Woo\PhpParser\ParserFactory::PREFER_PHP7, new \MailerLite_Woo\PhpParser\Lexer());
        try {
            $nodes = $parser->parse(\file_get_contents($filename));
            \assert($nodes !== null);
            $traverser = new \MailerLite_Woo\PhpParser\NodeTraverser();
            $visitor = new \MailerLite_Woo\SebastianBergmann\CodeCoverage\StaticAnalysis\ExecutableLinesFindingVisitor();
            $traverser->addVisitor($visitor);
            /* @noinspection UnusedFunctionResultInspection */
            $traverser->traverse($nodes);
            return $visitor->executableLines();
            // @codeCoverageIgnoreStart
        } catch (\MailerLite_Woo\PhpParser\Error $error) {
        }
        // @codeCoverageIgnoreEnd
        return [];
    }
}
