<?php

declare (strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\PHPUnit\Framework;

use function func_get_args;
use ArrayAccess;
use Countable;
use DOMDocument;
use DOMElement;
use MailerLite_Woo\PHPUnit\Framework\Constraint\ArrayHasKey;
use MailerLite_Woo\PHPUnit\Framework\Constraint\Callback;
use MailerLite_Woo\PHPUnit\Framework\Constraint\ClassHasAttribute;
use MailerLite_Woo\PHPUnit\Framework\Constraint\ClassHasStaticAttribute;
use MailerLite_Woo\PHPUnit\Framework\Constraint\Constraint;
use MailerLite_Woo\PHPUnit\Framework\Constraint\Count;
use MailerLite_Woo\PHPUnit\Framework\Constraint\DirectoryExists;
use MailerLite_Woo\PHPUnit\Framework\Constraint\FileExists;
use MailerLite_Woo\PHPUnit\Framework\Constraint\GreaterThan;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsAnything;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsEmpty;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsEqual;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsEqualCanonicalizing;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsEqualIgnoringCase;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsEqualWithDelta;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsFalse;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsFinite;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsIdentical;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsInfinite;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsInstanceOf;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsJson;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsNan;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsNull;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsReadable;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsTrue;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsType;
use MailerLite_Woo\PHPUnit\Framework\Constraint\IsWritable;
use MailerLite_Woo\PHPUnit\Framework\Constraint\LessThan;
use MailerLite_Woo\PHPUnit\Framework\Constraint\LogicalAnd;
use MailerLite_Woo\PHPUnit\Framework\Constraint\LogicalNot;
use MailerLite_Woo\PHPUnit\Framework\Constraint\LogicalOr;
use MailerLite_Woo\PHPUnit\Framework\Constraint\LogicalXor;
use MailerLite_Woo\PHPUnit\Framework\Constraint\ObjectEquals;
use MailerLite_Woo\PHPUnit\Framework\Constraint\ObjectHasAttribute;
use MailerLite_Woo\PHPUnit\Framework\Constraint\RegularExpression;
use MailerLite_Woo\PHPUnit\Framework\Constraint\StringContains;
use MailerLite_Woo\PHPUnit\Framework\Constraint\StringEndsWith;
use MailerLite_Woo\PHPUnit\Framework\Constraint\StringMatchesFormatDescription;
use MailerLite_Woo\PHPUnit\Framework\Constraint\StringStartsWith;
use MailerLite_Woo\PHPUnit\Framework\Constraint\TraversableContainsEqual;
use MailerLite_Woo\PHPUnit\Framework\Constraint\TraversableContainsIdentical;
use MailerLite_Woo\PHPUnit\Framework\Constraint\TraversableContainsOnly;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\AnyInvokedCount as AnyInvokedCountMatcher;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedAtIndex as InvokedAtIndexMatcher;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedAtLeastCount as InvokedAtLeastCountMatcher;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedAtLeastOnce as InvokedAtLeastOnceMatcher;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedAtMostCount as InvokedAtMostCountMatcher;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedCount as InvokedCountMatcher;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ConsecutiveCalls as ConsecutiveCallsStub;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\Exception as ExceptionStub;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnArgument as ReturnArgumentStub;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnCallback as ReturnCallbackStub;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnSelf as ReturnSelfStub;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnStub;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnValueMap as ReturnValueMapStub;
use Throwable;
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertArrayHasKey')) {
    /**
     * Asserts that an array has a specified key.
     *
     * @param int|string        $key
     * @param array|ArrayAccess $array
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertArrayHasKey
     */
    function assertArrayHasKey($key, $array, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertArrayHasKey(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertArrayNotHasKey')) {
    /**
     * Asserts that an array does not have a specified key.
     *
     * @param int|string        $key
     * @param array|ArrayAccess $array
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertArrayNotHasKey
     */
    function assertArrayNotHasKey($key, $array, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertArrayNotHasKey(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertContains')) {
    /**
     * Asserts that a haystack contains a needle.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertContains
     */
    function assertContains($needle, iterable $haystack, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertContains(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertContainsEquals')) {
    function assertContainsEquals($needle, iterable $haystack, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertContainsEquals(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotContains')) {
    /**
     * Asserts that a haystack does not contain a needle.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotContains
     */
    function assertNotContains($needle, iterable $haystack, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotContains(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotContainsEquals')) {
    function assertNotContainsEquals($needle, iterable $haystack, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotContainsEquals(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertContainsOnly')) {
    /**
     * Asserts that a haystack contains only values of a given type.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertContainsOnly
     */
    function assertContainsOnly(string $type, iterable $haystack, ?bool $isNativeType = null, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertContainsOnly(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertContainsOnlyInstancesOf')) {
    /**
     * Asserts that a haystack contains only instances of a given class name.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertContainsOnlyInstancesOf
     */
    function assertContainsOnlyInstancesOf(string $className, iterable $haystack, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertContainsOnlyInstancesOf(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotContainsOnly')) {
    /**
     * Asserts that a haystack does not contain only values of a given type.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotContainsOnly
     */
    function assertNotContainsOnly(string $type, iterable $haystack, ?bool $isNativeType = null, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotContainsOnly(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertCount')) {
    /**
     * Asserts the number of elements of an array, Countable or Traversable.
     *
     * @param Countable|iterable $haystack
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertCount
     */
    function assertCount(int $expectedCount, $haystack, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertCount(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotCount')) {
    /**
     * Asserts the number of elements of an array, Countable or Traversable.
     *
     * @param Countable|iterable $haystack
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotCount
     */
    function assertNotCount(int $expectedCount, $haystack, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotCount(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertEquals')) {
    /**
     * Asserts that two variables are equal.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertEquals
     */
    function assertEquals($expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertEquals(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertEqualsCanonicalizing')) {
    /**
     * Asserts that two variables are equal (canonicalizing).
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertEqualsCanonicalizing
     */
    function assertEqualsCanonicalizing($expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertEqualsCanonicalizing(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertEqualsIgnoringCase')) {
    /**
     * Asserts that two variables are equal (ignoring case).
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertEqualsIgnoringCase
     */
    function assertEqualsIgnoringCase($expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertEqualsIgnoringCase(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertEqualsWithDelta')) {
    /**
     * Asserts that two variables are equal (with delta).
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertEqualsWithDelta
     */
    function assertEqualsWithDelta($expected, $actual, float $delta, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertEqualsWithDelta(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotEquals')) {
    /**
     * Asserts that two variables are not equal.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotEquals
     */
    function assertNotEquals($expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotEquals(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotEqualsCanonicalizing')) {
    /**
     * Asserts that two variables are not equal (canonicalizing).
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotEqualsCanonicalizing
     */
    function assertNotEqualsCanonicalizing($expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotEqualsCanonicalizing(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotEqualsIgnoringCase')) {
    /**
     * Asserts that two variables are not equal (ignoring case).
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotEqualsIgnoringCase
     */
    function assertNotEqualsIgnoringCase($expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotEqualsIgnoringCase(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotEqualsWithDelta')) {
    /**
     * Asserts that two variables are not equal (with delta).
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotEqualsWithDelta
     */
    function assertNotEqualsWithDelta($expected, $actual, float $delta, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotEqualsWithDelta(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertObjectEquals')) {
    /**
     * @throws ExpectationFailedException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertObjectEquals
     */
    function assertObjectEquals(object $expected, object $actual, string $method = 'equals', string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertObjectEquals(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertEmpty')) {
    /**
     * Asserts that a variable is empty.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert empty $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertEmpty
     */
    function assertEmpty($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertEmpty(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotEmpty')) {
    /**
     * Asserts that a variable is not empty.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !empty $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotEmpty
     */
    function assertNotEmpty($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotEmpty(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertGreaterThan')) {
    /**
     * Asserts that a value is greater than another value.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertGreaterThan
     */
    function assertGreaterThan($expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertGreaterThan(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertGreaterThanOrEqual')) {
    /**
     * Asserts that a value is greater than or equal to another value.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertGreaterThanOrEqual
     */
    function assertGreaterThanOrEqual($expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertGreaterThanOrEqual(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertLessThan')) {
    /**
     * Asserts that a value is smaller than another value.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertLessThan
     */
    function assertLessThan($expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertLessThan(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertLessThanOrEqual')) {
    /**
     * Asserts that a value is smaller than or equal to another value.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertLessThanOrEqual
     */
    function assertLessThanOrEqual($expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertLessThanOrEqual(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileEquals')) {
    /**
     * Asserts that the contents of one file is equal to the contents of another
     * file.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileEquals
     */
    function assertFileEquals(string $expected, string $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileEquals(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileEqualsCanonicalizing')) {
    /**
     * Asserts that the contents of one file is equal to the contents of another
     * file (canonicalizing).
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileEqualsCanonicalizing
     */
    function assertFileEqualsCanonicalizing(string $expected, string $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileEqualsCanonicalizing(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileEqualsIgnoringCase')) {
    /**
     * Asserts that the contents of one file is equal to the contents of another
     * file (ignoring case).
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileEqualsIgnoringCase
     */
    function assertFileEqualsIgnoringCase(string $expected, string $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileEqualsIgnoringCase(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileNotEquals')) {
    /**
     * Asserts that the contents of one file is not equal to the contents of
     * another file.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileNotEquals
     */
    function assertFileNotEquals(string $expected, string $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileNotEquals(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileNotEqualsCanonicalizing')) {
    /**
     * Asserts that the contents of one file is not equal to the contents of another
     * file (canonicalizing).
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileNotEqualsCanonicalizing
     */
    function assertFileNotEqualsCanonicalizing(string $expected, string $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileNotEqualsCanonicalizing(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileNotEqualsIgnoringCase')) {
    /**
     * Asserts that the contents of one file is not equal to the contents of another
     * file (ignoring case).
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileNotEqualsIgnoringCase
     */
    function assertFileNotEqualsIgnoringCase(string $expected, string $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileNotEqualsIgnoringCase(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringEqualsFile')) {
    /**
     * Asserts that the contents of a string is equal
     * to the contents of a file.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringEqualsFile
     */
    function assertStringEqualsFile(string $expectedFile, string $actualString, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringEqualsFile(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringEqualsFileCanonicalizing')) {
    /**
     * Asserts that the contents of a string is equal
     * to the contents of a file (canonicalizing).
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringEqualsFileCanonicalizing
     */
    function assertStringEqualsFileCanonicalizing(string $expectedFile, string $actualString, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringEqualsFileCanonicalizing(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringEqualsFileIgnoringCase')) {
    /**
     * Asserts that the contents of a string is equal
     * to the contents of a file (ignoring case).
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringEqualsFileIgnoringCase
     */
    function assertStringEqualsFileIgnoringCase(string $expectedFile, string $actualString, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringEqualsFileIgnoringCase(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringNotEqualsFile')) {
    /**
     * Asserts that the contents of a string is not equal
     * to the contents of a file.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringNotEqualsFile
     */
    function assertStringNotEqualsFile(string $expectedFile, string $actualString, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringNotEqualsFile(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringNotEqualsFileCanonicalizing')) {
    /**
     * Asserts that the contents of a string is not equal
     * to the contents of a file (canonicalizing).
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringNotEqualsFileCanonicalizing
     */
    function assertStringNotEqualsFileCanonicalizing(string $expectedFile, string $actualString, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringNotEqualsFileCanonicalizing(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringNotEqualsFileIgnoringCase')) {
    /**
     * Asserts that the contents of a string is not equal
     * to the contents of a file (ignoring case).
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringNotEqualsFileIgnoringCase
     */
    function assertStringNotEqualsFileIgnoringCase(string $expectedFile, string $actualString, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringNotEqualsFileIgnoringCase(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsReadable')) {
    /**
     * Asserts that a file/dir is readable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsReadable
     */
    function assertIsReadable(string $filename, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsReadable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNotReadable')) {
    /**
     * Asserts that a file/dir exists and is not readable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNotReadable
     */
    function assertIsNotReadable(string $filename, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNotReadable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotIsReadable')) {
    /**
     * Asserts that a file/dir exists and is not readable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @codeCoverageIgnore
     *
     * @deprecated https://github.com/sebastianbergmann/phpunit/issues/4062
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotIsReadable
     */
    function assertNotIsReadable(string $filename, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotIsReadable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsWritable')) {
    /**
     * Asserts that a file/dir exists and is writable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsWritable
     */
    function assertIsWritable(string $filename, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsWritable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNotWritable')) {
    /**
     * Asserts that a file/dir exists and is not writable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNotWritable
     */
    function assertIsNotWritable(string $filename, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNotWritable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotIsWritable')) {
    /**
     * Asserts that a file/dir exists and is not writable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @codeCoverageIgnore
     *
     * @deprecated https://github.com/sebastianbergmann/phpunit/issues/4065
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotIsWritable
     */
    function assertNotIsWritable(string $filename, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotIsWritable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertDirectoryExists')) {
    /**
     * Asserts that a directory exists.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertDirectoryExists
     */
    function assertDirectoryExists(string $directory, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertDirectoryExists(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertDirectoryDoesNotExist')) {
    /**
     * Asserts that a directory does not exist.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertDirectoryDoesNotExist
     */
    function assertDirectoryDoesNotExist(string $directory, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertDirectoryDoesNotExist(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertDirectoryNotExists')) {
    /**
     * Asserts that a directory does not exist.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @codeCoverageIgnore
     *
     * @deprecated https://github.com/sebastianbergmann/phpunit/issues/4068
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertDirectoryNotExists
     */
    function assertDirectoryNotExists(string $directory, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertDirectoryNotExists(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertDirectoryIsReadable')) {
    /**
     * Asserts that a directory exists and is readable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertDirectoryIsReadable
     */
    function assertDirectoryIsReadable(string $directory, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertDirectoryIsReadable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertDirectoryIsNotReadable')) {
    /**
     * Asserts that a directory exists and is not readable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertDirectoryIsNotReadable
     */
    function assertDirectoryIsNotReadable(string $directory, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertDirectoryIsNotReadable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertDirectoryNotIsReadable')) {
    /**
     * Asserts that a directory exists and is not readable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @codeCoverageIgnore
     *
     * @deprecated https://github.com/sebastianbergmann/phpunit/issues/4071
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertDirectoryNotIsReadable
     */
    function assertDirectoryNotIsReadable(string $directory, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertDirectoryNotIsReadable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertDirectoryIsWritable')) {
    /**
     * Asserts that a directory exists and is writable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertDirectoryIsWritable
     */
    function assertDirectoryIsWritable(string $directory, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertDirectoryIsWritable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertDirectoryIsNotWritable')) {
    /**
     * Asserts that a directory exists and is not writable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertDirectoryIsNotWritable
     */
    function assertDirectoryIsNotWritable(string $directory, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertDirectoryIsNotWritable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertDirectoryNotIsWritable')) {
    /**
     * Asserts that a directory exists and is not writable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @codeCoverageIgnore
     *
     * @deprecated https://github.com/sebastianbergmann/phpunit/issues/4074
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertDirectoryNotIsWritable
     */
    function assertDirectoryNotIsWritable(string $directory, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertDirectoryNotIsWritable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileExists')) {
    /**
     * Asserts that a file exists.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileExists
     */
    function assertFileExists(string $filename, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileExists(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileDoesNotExist')) {
    /**
     * Asserts that a file does not exist.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileDoesNotExist
     */
    function assertFileDoesNotExist(string $filename, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileDoesNotExist(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileNotExists')) {
    /**
     * Asserts that a file does not exist.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @codeCoverageIgnore
     *
     * @deprecated https://github.com/sebastianbergmann/phpunit/issues/4077
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileNotExists
     */
    function assertFileNotExists(string $filename, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileNotExists(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileIsReadable')) {
    /**
     * Asserts that a file exists and is readable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileIsReadable
     */
    function assertFileIsReadable(string $file, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileIsReadable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileIsNotReadable')) {
    /**
     * Asserts that a file exists and is not readable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileIsNotReadable
     */
    function assertFileIsNotReadable(string $file, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileIsNotReadable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileNotIsReadable')) {
    /**
     * Asserts that a file exists and is not readable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @codeCoverageIgnore
     *
     * @deprecated https://github.com/sebastianbergmann/phpunit/issues/4080
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileNotIsReadable
     */
    function assertFileNotIsReadable(string $file, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileNotIsReadable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileIsWritable')) {
    /**
     * Asserts that a file exists and is writable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileIsWritable
     */
    function assertFileIsWritable(string $file, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileIsWritable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileIsNotWritable')) {
    /**
     * Asserts that a file exists and is not writable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileIsNotWritable
     */
    function assertFileIsNotWritable(string $file, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileIsNotWritable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFileNotIsWritable')) {
    /**
     * Asserts that a file exists and is not writable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @codeCoverageIgnore
     *
     * @deprecated https://github.com/sebastianbergmann/phpunit/issues/4083
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFileNotIsWritable
     */
    function assertFileNotIsWritable(string $file, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFileNotIsWritable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertTrue')) {
    /**
     * Asserts that a condition is true.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert true $condition
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertTrue
     */
    function assertTrue($condition, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertTrue(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotTrue')) {
    /**
     * Asserts that a condition is not true.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !true $condition
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotTrue
     */
    function assertNotTrue($condition, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotTrue(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFalse')) {
    /**
     * Asserts that a condition is false.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert false $condition
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFalse
     */
    function assertFalse($condition, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFalse(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotFalse')) {
    /**
     * Asserts that a condition is not false.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !false $condition
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotFalse
     */
    function assertNotFalse($condition, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotFalse(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNull')) {
    /**
     * Asserts that a variable is null.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert null $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNull
     */
    function assertNull($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNull(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotNull')) {
    /**
     * Asserts that a variable is not null.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !null $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotNull
     */
    function assertNotNull($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotNull(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertFinite')) {
    /**
     * Asserts that a variable is finite.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertFinite
     */
    function assertFinite($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertFinite(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertInfinite')) {
    /**
     * Asserts that a variable is infinite.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertInfinite
     */
    function assertInfinite($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertInfinite(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNan')) {
    /**
     * Asserts that a variable is nan.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNan
     */
    function assertNan($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNan(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertClassHasAttribute')) {
    /**
     * Asserts that a class has a specified attribute.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertClassHasAttribute
     */
    function assertClassHasAttribute(string $attributeName, string $className, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertClassHasAttribute(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertClassNotHasAttribute')) {
    /**
     * Asserts that a class does not have a specified attribute.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertClassNotHasAttribute
     */
    function assertClassNotHasAttribute(string $attributeName, string $className, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertClassNotHasAttribute(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertClassHasStaticAttribute')) {
    /**
     * Asserts that a class has a specified static attribute.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertClassHasStaticAttribute
     */
    function assertClassHasStaticAttribute(string $attributeName, string $className, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertClassHasStaticAttribute(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertClassNotHasStaticAttribute')) {
    /**
     * Asserts that a class does not have a specified static attribute.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertClassNotHasStaticAttribute
     */
    function assertClassNotHasStaticAttribute(string $attributeName, string $className, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertClassNotHasStaticAttribute(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertObjectHasAttribute')) {
    /**
     * Asserts that an object has a specified attribute.
     *
     * @param object $object
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertObjectHasAttribute
     */
    function assertObjectHasAttribute(string $attributeName, $object, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertObjectHasAttribute(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertObjectNotHasAttribute')) {
    /**
     * Asserts that an object does not have a specified attribute.
     *
     * @param object $object
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertObjectNotHasAttribute
     */
    function assertObjectNotHasAttribute(string $attributeName, $object, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertObjectNotHasAttribute(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertSame')) {
    /**
     * Asserts that two variables have the same type and value.
     * Used on objects, it asserts that two variables reference
     * the same object.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-template ExpectedType
     * @psalm-param ExpectedType $expected
     * @psalm-assert =ExpectedType $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertSame
     */
    function assertSame($expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertSame(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotSame')) {
    /**
     * Asserts that two variables do not have the same type and value.
     * Used on objects, it asserts that two variables do not reference
     * the same object.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotSame
     */
    function assertNotSame($expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotSame(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertInstanceOf')) {
    /**
     * Asserts that a variable is of a given type.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @psalm-template ExpectedType of object
     * @psalm-param class-string<ExpectedType> $expected
     * @psalm-assert =ExpectedType $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertInstanceOf
     */
    function assertInstanceOf(string $expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertInstanceOf(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotInstanceOf')) {
    /**
     * Asserts that a variable is not of a given type.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @psalm-template ExpectedType of object
     * @psalm-param class-string<ExpectedType> $expected
     * @psalm-assert !ExpectedType $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotInstanceOf
     */
    function assertNotInstanceOf(string $expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotInstanceOf(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsArray')) {
    /**
     * Asserts that a variable is of type array.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert array $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsArray
     */
    function assertIsArray($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsArray(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsBool')) {
    /**
     * Asserts that a variable is of type bool.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert bool $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsBool
     */
    function assertIsBool($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsBool(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsFloat')) {
    /**
     * Asserts that a variable is of type float.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert float $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsFloat
     */
    function assertIsFloat($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsFloat(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsInt')) {
    /**
     * Asserts that a variable is of type int.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert int $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsInt
     */
    function assertIsInt($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsInt(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNumeric')) {
    /**
     * Asserts that a variable is of type numeric.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert numeric $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNumeric
     */
    function assertIsNumeric($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNumeric(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsObject')) {
    /**
     * Asserts that a variable is of type object.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert object $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsObject
     */
    function assertIsObject($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsObject(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsResource')) {
    /**
     * Asserts that a variable is of type resource.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert resource $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsResource
     */
    function assertIsResource($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsResource(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsClosedResource')) {
    /**
     * Asserts that a variable is of type resource and is closed.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert resource $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsClosedResource
     */
    function assertIsClosedResource($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsClosedResource(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsString')) {
    /**
     * Asserts that a variable is of type string.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert string $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsString
     */
    function assertIsString($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsString(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsScalar')) {
    /**
     * Asserts that a variable is of type scalar.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert scalar $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsScalar
     */
    function assertIsScalar($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsScalar(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsCallable')) {
    /**
     * Asserts that a variable is of type callable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert callable $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsCallable
     */
    function assertIsCallable($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsCallable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsIterable')) {
    /**
     * Asserts that a variable is of type iterable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert iterable $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsIterable
     */
    function assertIsIterable($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsIterable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNotArray')) {
    /**
     * Asserts that a variable is not of type array.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !array $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNotArray
     */
    function assertIsNotArray($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNotArray(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNotBool')) {
    /**
     * Asserts that a variable is not of type bool.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !bool $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNotBool
     */
    function assertIsNotBool($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNotBool(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNotFloat')) {
    /**
     * Asserts that a variable is not of type float.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !float $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNotFloat
     */
    function assertIsNotFloat($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNotFloat(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNotInt')) {
    /**
     * Asserts that a variable is not of type int.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !int $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNotInt
     */
    function assertIsNotInt($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNotInt(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNotNumeric')) {
    /**
     * Asserts that a variable is not of type numeric.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !numeric $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNotNumeric
     */
    function assertIsNotNumeric($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNotNumeric(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNotObject')) {
    /**
     * Asserts that a variable is not of type object.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !object $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNotObject
     */
    function assertIsNotObject($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNotObject(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNotResource')) {
    /**
     * Asserts that a variable is not of type resource.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !resource $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNotResource
     */
    function assertIsNotResource($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNotResource(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNotClosedResource')) {
    /**
     * Asserts that a variable is not of type resource.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !resource $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNotClosedResource
     */
    function assertIsNotClosedResource($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNotClosedResource(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNotString')) {
    /**
     * Asserts that a variable is not of type string.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !string $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNotString
     */
    function assertIsNotString($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNotString(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNotScalar')) {
    /**
     * Asserts that a variable is not of type scalar.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !scalar $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNotScalar
     */
    function assertIsNotScalar($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNotScalar(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNotCallable')) {
    /**
     * Asserts that a variable is not of type callable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !callable $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNotCallable
     */
    function assertIsNotCallable($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNotCallable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertIsNotIterable')) {
    /**
     * Asserts that a variable is not of type iterable.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @psalm-assert !iterable $actual
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertIsNotIterable
     */
    function assertIsNotIterable($actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertIsNotIterable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertMatchesRegularExpression')) {
    /**
     * Asserts that a string matches a given regular expression.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertMatchesRegularExpression
     */
    function assertMatchesRegularExpression(string $pattern, string $string, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertMatchesRegularExpression(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertRegExp')) {
    /**
     * Asserts that a string matches a given regular expression.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @codeCoverageIgnore
     *
     * @deprecated https://github.com/sebastianbergmann/phpunit/issues/4086
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertRegExp
     */
    function assertRegExp(string $pattern, string $string, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertRegExp(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertDoesNotMatchRegularExpression')) {
    /**
     * Asserts that a string does not match a given regular expression.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertDoesNotMatchRegularExpression
     */
    function assertDoesNotMatchRegularExpression(string $pattern, string $string, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertDoesNotMatchRegularExpression(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotRegExp')) {
    /**
     * Asserts that a string does not match a given regular expression.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @codeCoverageIgnore
     *
     * @deprecated https://github.com/sebastianbergmann/phpunit/issues/4089
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotRegExp
     */
    function assertNotRegExp(string $pattern, string $string, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotRegExp(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertSameSize')) {
    /**
     * Assert that the size of two arrays (or `Countable` or `Traversable` objects)
     * is the same.
     *
     * @param Countable|iterable $expected
     * @param Countable|iterable $actual
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertSameSize
     */
    function assertSameSize($expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertSameSize(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertNotSameSize')) {
    /**
     * Assert that the size of two arrays (or `Countable` or `Traversable` objects)
     * is not the same.
     *
     * @param Countable|iterable $expected
     * @param Countable|iterable $actual
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertNotSameSize
     */
    function assertNotSameSize($expected, $actual, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertNotSameSize(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringMatchesFormat')) {
    /**
     * Asserts that a string matches a given format string.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringMatchesFormat
     */
    function assertStringMatchesFormat(string $format, string $string, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringMatchesFormat(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringNotMatchesFormat')) {
    /**
     * Asserts that a string does not match a given format string.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringNotMatchesFormat
     */
    function assertStringNotMatchesFormat(string $format, string $string, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringNotMatchesFormat(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringMatchesFormatFile')) {
    /**
     * Asserts that a string matches a given format file.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringMatchesFormatFile
     */
    function assertStringMatchesFormatFile(string $formatFile, string $string, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringMatchesFormatFile(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringNotMatchesFormatFile')) {
    /**
     * Asserts that a string does not match a given format string.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringNotMatchesFormatFile
     */
    function assertStringNotMatchesFormatFile(string $formatFile, string $string, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringNotMatchesFormatFile(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringStartsWith')) {
    /**
     * Asserts that a string starts with a given prefix.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringStartsWith
     */
    function assertStringStartsWith(string $prefix, string $string, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringStartsWith(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringStartsNotWith')) {
    /**
     * Asserts that a string starts not with a given prefix.
     *
     * @param string $prefix
     * @param string $string
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringStartsNotWith
     */
    function assertStringStartsNotWith($prefix, $string, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringStartsNotWith(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringContainsString')) {
    /**
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringContainsString
     */
    function assertStringContainsString(string $needle, string $haystack, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringContainsString(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringContainsStringIgnoringCase')) {
    /**
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringContainsStringIgnoringCase
     */
    function assertStringContainsStringIgnoringCase(string $needle, string $haystack, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringContainsStringIgnoringCase(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringNotContainsString')) {
    /**
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringNotContainsString
     */
    function assertStringNotContainsString(string $needle, string $haystack, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringNotContainsString(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringNotContainsStringIgnoringCase')) {
    /**
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringNotContainsStringIgnoringCase
     */
    function assertStringNotContainsStringIgnoringCase(string $needle, string $haystack, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringNotContainsStringIgnoringCase(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringEndsWith')) {
    /**
     * Asserts that a string ends with a given suffix.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringEndsWith
     */
    function assertStringEndsWith(string $suffix, string $string, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringEndsWith(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertStringEndsNotWith')) {
    /**
     * Asserts that a string ends not with a given suffix.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertStringEndsNotWith
     */
    function assertStringEndsNotWith(string $suffix, string $string, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertStringEndsNotWith(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertXmlFileEqualsXmlFile')) {
    /**
     * Asserts that two XML files are equal.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertXmlFileEqualsXmlFile
     */
    function assertXmlFileEqualsXmlFile(string $expectedFile, string $actualFile, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertXmlFileEqualsXmlFile(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertXmlFileNotEqualsXmlFile')) {
    /**
     * Asserts that two XML files are not equal.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws \PHPUnit\Util\Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertXmlFileNotEqualsXmlFile
     */
    function assertXmlFileNotEqualsXmlFile(string $expectedFile, string $actualFile, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertXmlFileNotEqualsXmlFile(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertXmlStringEqualsXmlFile')) {
    /**
     * Asserts that two XML documents are equal.
     *
     * @param DOMDocument|string $actualXml
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws \PHPUnit\Util\Xml\Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertXmlStringEqualsXmlFile
     */
    function assertXmlStringEqualsXmlFile(string $expectedFile, $actualXml, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertXmlStringEqualsXmlFile(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertXmlStringNotEqualsXmlFile')) {
    /**
     * Asserts that two XML documents are not equal.
     *
     * @param DOMDocument|string $actualXml
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws \PHPUnit\Util\Xml\Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertXmlStringNotEqualsXmlFile
     */
    function assertXmlStringNotEqualsXmlFile(string $expectedFile, $actualXml, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertXmlStringNotEqualsXmlFile(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertXmlStringEqualsXmlString')) {
    /**
     * Asserts that two XML documents are equal.
     *
     * @param DOMDocument|string $expectedXml
     * @param DOMDocument|string $actualXml
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws \PHPUnit\Util\Xml\Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertXmlStringEqualsXmlString
     */
    function assertXmlStringEqualsXmlString($expectedXml, $actualXml, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertXmlStringEqualsXmlString(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertXmlStringNotEqualsXmlString')) {
    /**
     * Asserts that two XML documents are not equal.
     *
     * @param DOMDocument|string $expectedXml
     * @param DOMDocument|string $actualXml
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     * @throws \PHPUnit\Util\Xml\Exception
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertXmlStringNotEqualsXmlString
     */
    function assertXmlStringNotEqualsXmlString($expectedXml, $actualXml, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertXmlStringNotEqualsXmlString(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertEqualXMLStructure')) {
    /**
     * Asserts that a hierarchy of DOMElements matches.
     *
     * @throws AssertionFailedError
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @codeCoverageIgnore
     *
     * @deprecated https://github.com/sebastianbergmann/phpunit/issues/4091
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertEqualXMLStructure
     */
    function assertEqualXMLStructure(\DOMElement $expectedElement, \DOMElement $actualElement, bool $checkAttributes = \false, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertEqualXMLStructure(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertThat')) {
    /**
     * Evaluates a PHPUnit\Framework\Constraint matcher object.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertThat
     */
    function assertThat($value, \MailerLite_Woo\PHPUnit\Framework\Constraint\Constraint $constraint, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertThat(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertJson')) {
    /**
     * Asserts that a string is a valid JSON string.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertJson
     */
    function assertJson(string $actualJson, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertJson(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertJsonStringEqualsJsonString')) {
    /**
     * Asserts that two given JSON encoded objects or arrays are equal.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertJsonStringEqualsJsonString
     */
    function assertJsonStringEqualsJsonString(string $expectedJson, string $actualJson, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertJsonStringEqualsJsonString(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertJsonStringNotEqualsJsonString')) {
    /**
     * Asserts that two given JSON encoded objects or arrays are not equal.
     *
     * @param string $expectedJson
     * @param string $actualJson
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertJsonStringNotEqualsJsonString
     */
    function assertJsonStringNotEqualsJsonString($expectedJson, $actualJson, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertJsonStringNotEqualsJsonString(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertJsonStringEqualsJsonFile')) {
    /**
     * Asserts that the generated JSON encoded object and the content of the given file are equal.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertJsonStringEqualsJsonFile
     */
    function assertJsonStringEqualsJsonFile(string $expectedFile, string $actualJson, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertJsonStringEqualsJsonFile(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertJsonStringNotEqualsJsonFile')) {
    /**
     * Asserts that the generated JSON encoded object and the content of the given file are not equal.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertJsonStringNotEqualsJsonFile
     */
    function assertJsonStringNotEqualsJsonFile(string $expectedFile, string $actualJson, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertJsonStringNotEqualsJsonFile(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertJsonFileEqualsJsonFile')) {
    /**
     * Asserts that two JSON files are equal.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertJsonFileEqualsJsonFile
     */
    function assertJsonFileEqualsJsonFile(string $expectedFile, string $actualFile, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertJsonFileEqualsJsonFile(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\assertJsonFileNotEqualsJsonFile')) {
    /**
     * Asserts that two JSON files are not equal.
     *
     * @throws ExpectationFailedException
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     *
     * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
     *
     * @see Assert::assertJsonFileNotEqualsJsonFile
     */
    function assertJsonFileNotEqualsJsonFile(string $expectedFile, string $actualFile, string $message = '') : void
    {
        \MailerLite_Woo\PHPUnit\Framework\Assert::assertJsonFileNotEqualsJsonFile(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\logicalAnd')) {
    function logicalAnd() : \MailerLite_Woo\PHPUnit\Framework\Constraint\LogicalAnd
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::logicalAnd(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\logicalOr')) {
    function logicalOr() : \MailerLite_Woo\PHPUnit\Framework\Constraint\LogicalOr
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::logicalOr(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\logicalNot')) {
    function logicalNot(\MailerLite_Woo\PHPUnit\Framework\Constraint\Constraint $constraint) : \MailerLite_Woo\PHPUnit\Framework\Constraint\LogicalNot
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::logicalNot(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\logicalXor')) {
    function logicalXor() : \MailerLite_Woo\PHPUnit\Framework\Constraint\LogicalXor
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::logicalXor(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\anything')) {
    function anything() : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsAnything
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::anything(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\isTrue')) {
    function isTrue() : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsTrue
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::isTrue(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\callback')) {
    function callback(callable $callback) : \MailerLite_Woo\PHPUnit\Framework\Constraint\Callback
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::callback(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\isFalse')) {
    function isFalse() : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsFalse
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::isFalse(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\isJson')) {
    function isJson() : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsJson
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::isJson(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\isNull')) {
    function isNull() : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsNull
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::isNull(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\isFinite')) {
    function isFinite() : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsFinite
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::isFinite(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\isInfinite')) {
    function isInfinite() : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsInfinite
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::isInfinite(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\isNan')) {
    function isNan() : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsNan
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::isNan(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\containsEqual')) {
    function containsEqual($value) : \MailerLite_Woo\PHPUnit\Framework\Constraint\TraversableContainsEqual
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::containsEqual(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\containsIdentical')) {
    function containsIdentical($value) : \MailerLite_Woo\PHPUnit\Framework\Constraint\TraversableContainsIdentical
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::containsIdentical(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\containsOnly')) {
    function containsOnly(string $type) : \MailerLite_Woo\PHPUnit\Framework\Constraint\TraversableContainsOnly
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::containsOnly(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\containsOnlyInstancesOf')) {
    function containsOnlyInstancesOf(string $className) : \MailerLite_Woo\PHPUnit\Framework\Constraint\TraversableContainsOnly
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::containsOnlyInstancesOf(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\arrayHasKey')) {
    function arrayHasKey($key) : \MailerLite_Woo\PHPUnit\Framework\Constraint\ArrayHasKey
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::arrayHasKey(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\equalTo')) {
    function equalTo($value) : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsEqual
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::equalTo(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\equalToCanonicalizing')) {
    function equalToCanonicalizing($value) : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsEqualCanonicalizing
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::equalToCanonicalizing(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\equalToIgnoringCase')) {
    function equalToIgnoringCase($value) : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsEqualIgnoringCase
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::equalToIgnoringCase(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\equalToWithDelta')) {
    function equalToWithDelta($value, float $delta) : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsEqualWithDelta
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::equalToWithDelta(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\isEmpty')) {
    function isEmpty() : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsEmpty
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::isEmpty(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\isWritable')) {
    function isWritable() : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsWritable
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::isWritable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\isReadable')) {
    function isReadable() : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsReadable
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::isReadable(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\directoryExists')) {
    function directoryExists() : \MailerLite_Woo\PHPUnit\Framework\Constraint\DirectoryExists
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::directoryExists(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\fileExists')) {
    function fileExists() : \MailerLite_Woo\PHPUnit\Framework\Constraint\FileExists
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::fileExists(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\greaterThan')) {
    function greaterThan($value) : \MailerLite_Woo\PHPUnit\Framework\Constraint\GreaterThan
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::greaterThan(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\greaterThanOrEqual')) {
    function greaterThanOrEqual($value) : \MailerLite_Woo\PHPUnit\Framework\Constraint\LogicalOr
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::greaterThanOrEqual(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\classHasAttribute')) {
    function classHasAttribute(string $attributeName) : \MailerLite_Woo\PHPUnit\Framework\Constraint\ClassHasAttribute
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::classHasAttribute(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\classHasStaticAttribute')) {
    function classHasStaticAttribute(string $attributeName) : \MailerLite_Woo\PHPUnit\Framework\Constraint\ClassHasStaticAttribute
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::classHasStaticAttribute(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\objectHasAttribute')) {
    function objectHasAttribute($attributeName) : \MailerLite_Woo\PHPUnit\Framework\Constraint\ObjectHasAttribute
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::objectHasAttribute(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\identicalTo')) {
    function identicalTo($value) : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsIdentical
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::identicalTo(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\isInstanceOf')) {
    function isInstanceOf(string $className) : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsInstanceOf
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::isInstanceOf(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\isType')) {
    function isType(string $type) : \MailerLite_Woo\PHPUnit\Framework\Constraint\IsType
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::isType(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\lessThan')) {
    function lessThan($value) : \MailerLite_Woo\PHPUnit\Framework\Constraint\LessThan
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::lessThan(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\lessThanOrEqual')) {
    function lessThanOrEqual($value) : \MailerLite_Woo\PHPUnit\Framework\Constraint\LogicalOr
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::lessThanOrEqual(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\matchesRegularExpression')) {
    function matchesRegularExpression(string $pattern) : \MailerLite_Woo\PHPUnit\Framework\Constraint\RegularExpression
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::matchesRegularExpression(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\matches')) {
    function matches(string $string) : \MailerLite_Woo\PHPUnit\Framework\Constraint\StringMatchesFormatDescription
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::matches(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\stringStartsWith')) {
    function stringStartsWith($prefix) : \MailerLite_Woo\PHPUnit\Framework\Constraint\StringStartsWith
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::stringStartsWith(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\stringContains')) {
    function stringContains(string $string, bool $case = \true) : \MailerLite_Woo\PHPUnit\Framework\Constraint\StringContains
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::stringContains(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\stringEndsWith')) {
    function stringEndsWith(string $suffix) : \MailerLite_Woo\PHPUnit\Framework\Constraint\StringEndsWith
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::stringEndsWith(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\countOf')) {
    function countOf(int $count) : \MailerLite_Woo\PHPUnit\Framework\Constraint\Count
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::countOf(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\objectEquals')) {
    function objectEquals(object $object, string $method = 'equals') : \MailerLite_Woo\PHPUnit\Framework\Constraint\ObjectEquals
    {
        return \MailerLite_Woo\PHPUnit\Framework\Assert::objectEquals(...\func_get_args());
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\any')) {
    /**
     * Returns a matcher that matches when the method is executed
     * zero or more times.
     */
    function any() : \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\AnyInvokedCount
    {
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\AnyInvokedCount();
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\never')) {
    /**
     * Returns a matcher that matches when the method is never executed.
     */
    function never() : \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedCount
    {
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedCount(0);
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\atLeast')) {
    /**
     * Returns a matcher that matches when the method is executed
     * at least N times.
     */
    function atLeast(int $requiredInvocations) : \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedAtLeastCount
    {
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedAtLeastCount($requiredInvocations);
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\atLeastOnce')) {
    /**
     * Returns a matcher that matches when the method is executed at least once.
     */
    function atLeastOnce() : \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedAtLeastOnce
    {
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedAtLeastOnce();
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\once')) {
    /**
     * Returns a matcher that matches when the method is executed exactly once.
     */
    function once() : \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedCount
    {
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedCount(1);
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\exactly')) {
    /**
     * Returns a matcher that matches when the method is executed
     * exactly $count times.
     */
    function exactly(int $count) : \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedCount
    {
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedCount($count);
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\atMost')) {
    /**
     * Returns a matcher that matches when the method is executed
     * at most N times.
     */
    function atMost(int $allowedInvocations) : \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedAtMostCount
    {
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedAtMostCount($allowedInvocations);
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\at')) {
    /**
     * Returns a matcher that matches when the method is executed
     * at the given index.
     */
    function at(int $index) : \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedAtIndex
    {
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvokedAtIndex($index);
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\returnValue')) {
    function returnValue($value) : \MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnStub
    {
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnStub($value);
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\returnValueMap')) {
    function returnValueMap(array $valueMap) : \MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnValueMap
    {
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnValueMap($valueMap);
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\returnArgument')) {
    function returnArgument(int $argumentIndex) : \MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnArgument
    {
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnArgument($argumentIndex);
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\returnCallback')) {
    function returnCallback($callback) : \MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnCallback
    {
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnCallback($callback);
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\returnSelf')) {
    /**
     * Returns the current object.
     *
     * This method is useful when mocking a fluent interface.
     */
    function returnSelf() : \MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnSelf
    {
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ReturnSelf();
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\throwException')) {
    function throwException(\Throwable $exception) : \MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\Exception
    {
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\Exception($exception);
    }
}
if (!\function_exists('MailerLite_Woo\\PHPUnit\\Framework\\onConsecutiveCalls')) {
    function onConsecutiveCalls() : \MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ConsecutiveCalls
    {
        $args = \func_get_args();
        return new \MailerLite_Woo\PHPUnit\Framework\MockObject\Stub\ConsecutiveCalls($args);
    }
}
