<?php

declare (strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\PHPUnit\Framework\Constraint;

use function preg_match;
use function sprintf;
/**
 * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
 */
class RegularExpression extends \MailerLite_Woo\PHPUnit\Framework\Constraint\Constraint
{
    /**
     * @var string
     */
    private $pattern;
    public function __construct(string $pattern)
    {
        $this->pattern = $pattern;
    }
    /**
     * Returns a string representation of the constraint.
     */
    public function toString() : string
    {
        return \sprintf('matches PCRE pattern "%s"', $this->pattern);
    }
    /**
     * Evaluates the constraint for parameter $other. Returns true if the
     * constraint is met, false otherwise.
     *
     * @param mixed $other value or object to evaluate
     */
    protected function matches($other) : bool
    {
        return \preg_match($this->pattern, $other) > 0;
    }
}
