<?php

declare (strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\PHPUnit\Framework\Constraint;

use function strlen;
use function strpos;
use MailerLite_Woo\PHPUnit\Framework\InvalidArgumentException;
/**
 * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
 */
final class StringStartsWith extends \MailerLite_Woo\PHPUnit\Framework\Constraint\Constraint
{
    /**
     * @var string
     */
    private $prefix;
    public function __construct(string $prefix)
    {
        if (\strlen($prefix) === 0) {
            throw \MailerLite_Woo\PHPUnit\Framework\InvalidArgumentException::create(1, 'non-empty string');
        }
        $this->prefix = $prefix;
    }
    /**
     * Returns a string representation of the constraint.
     */
    public function toString() : string
    {
        return 'starts with "' . $this->prefix . '"';
    }
    /**
     * Evaluates the constraint for parameter $other. Returns true if the
     * constraint is met, false otherwise.
     *
     * @param mixed $other value or object to evaluate
     */
    protected function matches($other) : bool
    {
        return \strpos((string) $other, $this->prefix) === 0;
    }
}
