<?php

declare (strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\PHPUnit\Framework\MockObject\Rule;

use function sprintf;
use MailerLite_Woo\PHPUnit\Framework\ExpectationFailedException;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Invocation as BaseInvocation;
/**
 * @internal This class is not covered by the backward compatibility promise for PHPUnit
 *
 * @deprecated https://github.com/sebastianbergmann/phpunit/issues/4297
 * @codeCoverageIgnore
 */
final class InvokedAtIndex extends \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvocationOrder
{
    /**
     * @var int
     */
    private $sequenceIndex;
    /**
     * @var int
     */
    private $currentIndex = -1;
    /**
     * @param int $sequenceIndex
     */
    public function __construct($sequenceIndex)
    {
        $this->sequenceIndex = $sequenceIndex;
    }
    public function toString() : string
    {
        return 'invoked at sequence index ' . $this->sequenceIndex;
    }
    public function matches(\MailerLite_Woo\PHPUnit\Framework\MockObject\Invocation $invocation) : bool
    {
        $this->currentIndex++;
        return $this->currentIndex == $this->sequenceIndex;
    }
    /**
     * Verifies that the current expectation is valid. If everything is OK the
     * code should just return, if not it must throw an exception.
     *
     * @throws ExpectationFailedException
     */
    public function verify() : void
    {
        if ($this->currentIndex < $this->sequenceIndex) {
            throw new \MailerLite_Woo\PHPUnit\Framework\ExpectationFailedException(\sprintf('The expected invocation at index %s was never reached.', $this->sequenceIndex));
        }
    }
    protected function invokedDo(\MailerLite_Woo\PHPUnit\Framework\MockObject\Invocation $invocation) : void
    {
    }
}
