<?php

declare (strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\PHPUnit\Framework\MockObject\Rule;

use MailerLite_Woo\PHPUnit\Framework\ExpectationFailedException;
use MailerLite_Woo\PHPUnit\Framework\MockObject\Invocation as BaseInvocation;
/**
 * @internal This class is not covered by the backward compatibility promise for PHPUnit
 */
final class InvokedAtLeastCount extends \MailerLite_Woo\PHPUnit\Framework\MockObject\Rule\InvocationOrder
{
    /**
     * @var int
     */
    private $requiredInvocations;
    /**
     * @param int $requiredInvocations
     */
    public function __construct($requiredInvocations)
    {
        $this->requiredInvocations = $requiredInvocations;
    }
    public function toString() : string
    {
        return 'invoked at least ' . $this->requiredInvocations . ' times';
    }
    /**
     * Verifies that the current expectation is valid. If everything is OK the
     * code should just return, if not it must throw an exception.
     *
     * @throws ExpectationFailedException
     */
    public function verify() : void
    {
        $count = $this->getInvocationCount();
        if ($count < $this->requiredInvocations) {
            throw new \MailerLite_Woo\PHPUnit\Framework\ExpectationFailedException('Expected invocation at least ' . $this->requiredInvocations . ' times but it occurred ' . $count . ' time(s).');
        }
    }
    public function matches(\MailerLite_Woo\PHPUnit\Framework\MockObject\Invocation $invocation) : bool
    {
        return \true;
    }
    protected function invokedDo(\MailerLite_Woo\PHPUnit\Framework\MockObject\Invocation $invocation) : void
    {
    }
}
