<?php

declare (strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\PHPUnit\Runner\Extension;

use function class_exists;
use function sprintf;
use MailerLite_Woo\PHPUnit\Framework\TestListener;
use MailerLite_Woo\PHPUnit\Runner\Exception;
use MailerLite_Woo\PHPUnit\Runner\Hook;
use MailerLite_Woo\PHPUnit\TextUI\TestRunner;
use MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\Extension;
use ReflectionClass;
use ReflectionException;
/**
 * @internal This class is not covered by the backward compatibility promise for PHPUnit
 */
final class ExtensionHandler
{
    /**
     * @throws Exception
     */
    public function registerExtension(\MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\Extension $extensionConfiguration, \MailerLite_Woo\PHPUnit\TextUI\TestRunner $runner) : void
    {
        $extension = $this->createInstance($extensionConfiguration);
        if (!$extension instanceof \MailerLite_Woo\PHPUnit\Runner\Hook) {
            throw new \MailerLite_Woo\PHPUnit\Runner\Exception(\sprintf('Class "%s" does not implement a PHPUnit\\Runner\\Hook interface', $extensionConfiguration->className()));
        }
        $runner->addExtension($extension);
    }
    /**
     * @throws Exception
     *
     * @deprecated
     */
    public function createTestListenerInstance(\MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\Extension $listenerConfiguration) : \MailerLite_Woo\PHPUnit\Framework\TestListener
    {
        $listener = $this->createInstance($listenerConfiguration);
        if (!$listener instanceof \MailerLite_Woo\PHPUnit\Framework\TestListener) {
            throw new \MailerLite_Woo\PHPUnit\Runner\Exception(\sprintf('Class "%s" does not implement the PHPUnit\\Framework\\TestListener interface', $listenerConfiguration->className()));
        }
        return $listener;
    }
    /**
     * @throws Exception
     */
    private function createInstance(\MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\Extension $extensionConfiguration) : object
    {
        $this->ensureClassExists($extensionConfiguration);
        try {
            $reflector = new \ReflectionClass($extensionConfiguration->className());
        } catch (\ReflectionException $e) {
            throw new \MailerLite_Woo\PHPUnit\Runner\Exception($e->getMessage(), (int) $e->getCode(), $e);
        }
        if (!$extensionConfiguration->hasArguments()) {
            return $reflector->newInstance();
        }
        return $reflector->newInstanceArgs($extensionConfiguration->arguments());
    }
    /**
     * @throws Exception
     */
    private function ensureClassExists(\MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\Extension $extensionConfiguration) : void
    {
        if (\class_exists($extensionConfiguration->className(), \false)) {
            return;
        }
        if ($extensionConfiguration->hasSourceFile()) {
            /**
             * @noinspection PhpIncludeInspection
             * @psalm-suppress UnresolvableInclude
             */
            require_once $extensionConfiguration->sourceFile();
        }
        if (!\class_exists($extensionConfiguration->className())) {
            throw new \MailerLite_Woo\PHPUnit\Runner\Exception(\sprintf('Class "%s" does not exist', $extensionConfiguration->className()));
        }
    }
}
