<?php

declare (strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration;

use MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\CodeCoverage\CodeCoverage;
use MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\Logging\Logging;
use MailerLite_Woo\PHPUnit\Util\Xml\ValidationResult;
/**
 * @internal This class is not covered by the backward compatibility promise for PHPUnit
 * @psalm-immutable
 */
final class Configuration
{
    /**
     * @var string
     */
    private $filename;
    /**
     * @var ValidationResult
     */
    private $validationResult;
    /**
     * @var ExtensionCollection
     */
    private $extensions;
    /**
     * @var CodeCoverage
     */
    private $codeCoverage;
    /**
     * @var Groups
     */
    private $groups;
    /**
     * @var Groups
     */
    private $testdoxGroups;
    /**
     * @var ExtensionCollection
     */
    private $listeners;
    /**
     * @var Logging
     */
    private $logging;
    /**
     * @var Php
     */
    private $php;
    /**
     * @var PHPUnit
     */
    private $phpunit;
    /**
     * @var TestSuiteCollection
     */
    private $testSuite;
    public function __construct(string $filename, \MailerLite_Woo\PHPUnit\Util\Xml\ValidationResult $validationResult, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\ExtensionCollection $extensions, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\CodeCoverage\CodeCoverage $codeCoverage, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\Groups $groups, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\Groups $testdoxGroups, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\ExtensionCollection $listeners, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\Logging\Logging $logging, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\Php $php, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\PHPUnit $phpunit, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\TestSuiteCollection $testSuite)
    {
        $this->filename = $filename;
        $this->validationResult = $validationResult;
        $this->extensions = $extensions;
        $this->codeCoverage = $codeCoverage;
        $this->groups = $groups;
        $this->testdoxGroups = $testdoxGroups;
        $this->listeners = $listeners;
        $this->logging = $logging;
        $this->php = $php;
        $this->phpunit = $phpunit;
        $this->testSuite = $testSuite;
    }
    public function filename() : string
    {
        return $this->filename;
    }
    public function hasValidationErrors() : bool
    {
        return $this->validationResult->hasValidationErrors();
    }
    public function validationErrors() : string
    {
        return $this->validationResult->asString();
    }
    public function extensions() : \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\ExtensionCollection
    {
        return $this->extensions;
    }
    public function codeCoverage() : \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\CodeCoverage\CodeCoverage
    {
        return $this->codeCoverage;
    }
    public function groups() : \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\Groups
    {
        return $this->groups;
    }
    public function testdoxGroups() : \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\Groups
    {
        return $this->testdoxGroups;
    }
    public function listeners() : \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\ExtensionCollection
    {
        return $this->listeners;
    }
    public function logging() : \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\Logging\Logging
    {
        return $this->logging;
    }
    public function php() : \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\Php
    {
        return $this->php;
    }
    public function phpunit() : \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\PHPUnit
    {
        return $this->phpunit;
    }
    public function testSuite() : \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\TestSuiteCollection
    {
        return $this->testSuite;
    }
}
