<?php

declare (strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration;

use function array_key_exists;
use function sprintf;
use function version_compare;
/**
 * @internal This class is not covered by the backward compatibility promise for PHPUnit
 */
final class MigrationBuilder
{
    private const AVAILABLE_MIGRATIONS = ['8.5' => [\MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\RemoveLogTypes::class], '9.2' => [\MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\RemoveCacheTokensAttribute::class, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\IntroduceCoverageElement::class, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\MoveAttributesFromRootToCoverage::class, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\MoveAttributesFromFilterWhitelistToCoverage::class, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\MoveWhitelistDirectoriesToCoverage::class, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\MoveWhitelistExcludesToCoverage::class, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\RemoveEmptyFilter::class, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\CoverageCloverToReport::class, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\CoverageCrap4jToReport::class, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\CoverageHtmlToReport::class, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\CoveragePhpToReport::class, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\CoverageTextToReport::class, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\CoverageXmlToReport::class, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\ConvertLogTypes::class, \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\UpdateSchemaLocationTo93::class]];
    /**
     * @throws MigrationBuilderException
     */
    public function build(string $fromVersion) : array
    {
        if (!\array_key_exists($fromVersion, self::AVAILABLE_MIGRATIONS)) {
            throw new \MailerLite_Woo\PHPUnit\TextUI\XmlConfiguration\MigrationBuilderException(\sprintf('Migration from schema version %s is not supported', $fromVersion));
        }
        $stack = [];
        foreach (self::AVAILABLE_MIGRATIONS as $version => $migrations) {
            if (\version_compare($version, $fromVersion, '<')) {
                continue;
            }
            foreach ($migrations as $migration) {
                $stack[] = new $migration();
            }
        }
        return $stack;
    }
}
