<?php

declare (strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\PHPUnit\Util;

use const PHP_EOL;
use function get_class;
use function sprintf;
use function str_replace;
use MailerLite_Woo\PHPUnit\Framework\TestCase;
use MailerLite_Woo\PHPUnit\Framework\TestSuite;
use MailerLite_Woo\PHPUnit\Runner\PhptTestCase;
use RecursiveIteratorIterator;
/**
 * @internal This class is not covered by the backward compatibility promise for PHPUnit
 */
final class TextTestListRenderer
{
    /**
     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
     */
    public function render(\MailerLite_Woo\PHPUnit\Framework\TestSuite $suite) : string
    {
        $buffer = 'Available test(s):' . \PHP_EOL;
        foreach (new \RecursiveIteratorIterator($suite->getIterator()) as $test) {
            if ($test instanceof \MailerLite_Woo\PHPUnit\Framework\TestCase) {
                $name = \sprintf('%s::%s', \get_class($test), \str_replace(' with data set ', '', $test->getName()));
            } elseif ($test instanceof \MailerLite_Woo\PHPUnit\Runner\PhptTestCase) {
                $name = $test->getName();
            } else {
                continue;
            }
            $buffer .= \sprintf(' - %s' . \PHP_EOL, $name);
        }
        return $buffer;
    }
}
