<?php

declare (strict_types=1);
/*
 * This file is part of sebastian/complexity.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\SebastianBergmann\Complexity;

use MailerLite_Woo\PhpParser\Error;
use MailerLite_Woo\PhpParser\Lexer;
use MailerLite_Woo\PhpParser\Node;
use MailerLite_Woo\PhpParser\NodeTraverser;
use MailerLite_Woo\PhpParser\NodeVisitor\NameResolver;
use MailerLite_Woo\PhpParser\NodeVisitor\ParentConnectingVisitor;
use MailerLite_Woo\PhpParser\Parser;
use MailerLite_Woo\PhpParser\ParserFactory;
final class Calculator
{
    /**
     * @throws RuntimeException
     */
    public function calculateForSourceFile(string $sourceFile) : \MailerLite_Woo\SebastianBergmann\Complexity\ComplexityCollection
    {
        return $this->calculateForSourceString(\file_get_contents($sourceFile));
    }
    /**
     * @throws RuntimeException
     */
    public function calculateForSourceString(string $source) : \MailerLite_Woo\SebastianBergmann\Complexity\ComplexityCollection
    {
        try {
            $nodes = $this->parser()->parse($source);
            \assert($nodes !== null);
            return $this->calculateForAbstractSyntaxTree($nodes);
            // @codeCoverageIgnoreStart
        } catch (\MailerLite_Woo\PhpParser\Error $error) {
            throw new \MailerLite_Woo\SebastianBergmann\Complexity\RuntimeException($error->getMessage(), (int) $error->getCode(), $error);
        }
        // @codeCoverageIgnoreEnd
    }
    /**
     * @param Node[] $nodes
     *
     * @throws RuntimeException
     */
    public function calculateForAbstractSyntaxTree(array $nodes) : \MailerLite_Woo\SebastianBergmann\Complexity\ComplexityCollection
    {
        $traverser = new \MailerLite_Woo\PhpParser\NodeTraverser();
        $complexityCalculatingVisitor = new \MailerLite_Woo\SebastianBergmann\Complexity\ComplexityCalculatingVisitor(\true);
        $traverser->addVisitor(new \MailerLite_Woo\PhpParser\NodeVisitor\NameResolver());
        $traverser->addVisitor(new \MailerLite_Woo\PhpParser\NodeVisitor\ParentConnectingVisitor());
        $traverser->addVisitor($complexityCalculatingVisitor);
        try {
            /* @noinspection UnusedFunctionResultInspection */
            $traverser->traverse($nodes);
            // @codeCoverageIgnoreStart
        } catch (\MailerLite_Woo\PhpParser\Error $error) {
            throw new \MailerLite_Woo\SebastianBergmann\Complexity\RuntimeException($error->getMessage(), (int) $error->getCode(), $error);
        }
        // @codeCoverageIgnoreEnd
        return $complexityCalculatingVisitor->result();
    }
    private function parser() : \MailerLite_Woo\PhpParser\Parser
    {
        return (new \MailerLite_Woo\PhpParser\ParserFactory())->create(\MailerLite_Woo\PhpParser\ParserFactory::PREFER_PHP7, new \MailerLite_Woo\PhpParser\Lexer());
    }
}
