<?php

declare (strict_types=1);
/*
 * This file is part of sebastian/complexity.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\SebastianBergmann\Complexity;

use function get_class;
use MailerLite_Woo\PhpParser\Node;
use MailerLite_Woo\PhpParser\Node\Expr\BinaryOp\BooleanAnd;
use MailerLite_Woo\PhpParser\Node\Expr\BinaryOp\BooleanOr;
use MailerLite_Woo\PhpParser\Node\Expr\BinaryOp\LogicalAnd;
use MailerLite_Woo\PhpParser\Node\Expr\BinaryOp\LogicalOr;
use MailerLite_Woo\PhpParser\Node\Expr\Ternary;
use MailerLite_Woo\PhpParser\Node\Stmt\Case_;
use MailerLite_Woo\PhpParser\Node\Stmt\Catch_;
use MailerLite_Woo\PhpParser\Node\Stmt\ElseIf_;
use MailerLite_Woo\PhpParser\Node\Stmt\For_;
use MailerLite_Woo\PhpParser\Node\Stmt\Foreach_;
use MailerLite_Woo\PhpParser\Node\Stmt\If_;
use MailerLite_Woo\PhpParser\Node\Stmt\While_;
use MailerLite_Woo\PhpParser\NodeVisitorAbstract;
final class CyclomaticComplexityCalculatingVisitor extends \MailerLite_Woo\PhpParser\NodeVisitorAbstract
{
    /**
     * @var int
     */
    private $cyclomaticComplexity = 1;
    public function enterNode(\MailerLite_Woo\PhpParser\Node $node) : void
    {
        /* @noinspection GetClassMissUseInspection */
        switch (\get_class($node)) {
            case \MailerLite_Woo\PhpParser\Node\Expr\BinaryOp\BooleanAnd::class:
            case \MailerLite_Woo\PhpParser\Node\Expr\BinaryOp\BooleanOr::class:
            case \MailerLite_Woo\PhpParser\Node\Stmt\Case_::class:
            case \MailerLite_Woo\PhpParser\Node\Stmt\Catch_::class:
            case \MailerLite_Woo\PhpParser\Node\Stmt\ElseIf_::class:
            case \MailerLite_Woo\PhpParser\Node\Stmt\For_::class:
            case \MailerLite_Woo\PhpParser\Node\Stmt\Foreach_::class:
            case \MailerLite_Woo\PhpParser\Node\Stmt\If_::class:
            case \MailerLite_Woo\PhpParser\Node\Expr\BinaryOp\LogicalAnd::class:
            case \MailerLite_Woo\PhpParser\Node\Expr\BinaryOp\LogicalOr::class:
            case \MailerLite_Woo\PhpParser\Node\Expr\Ternary::class:
            case \MailerLite_Woo\PhpParser\Node\Stmt\While_::class:
                $this->cyclomaticComplexity++;
        }
    }
    public function cyclomaticComplexity() : int
    {
        return $this->cyclomaticComplexity;
    }
}
