<?php

declare (strict_types=1);
/*
 * This file is part of sebastian/lines-of-code.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\SebastianBergmann\LinesOfCode;

use function substr_count;
use MailerLite_Woo\PhpParser\Error;
use MailerLite_Woo\PhpParser\Lexer;
use MailerLite_Woo\PhpParser\Node;
use MailerLite_Woo\PhpParser\NodeTraverser;
use MailerLite_Woo\PhpParser\Parser;
use MailerLite_Woo\PhpParser\ParserFactory;
final class Counter
{
    /**
     * @throws RuntimeException
     */
    public function countInSourceFile(string $sourceFile) : \MailerLite_Woo\SebastianBergmann\LinesOfCode\LinesOfCode
    {
        return $this->countInSourceString(\file_get_contents($sourceFile));
    }
    /**
     * @throws RuntimeException
     */
    public function countInSourceString(string $source) : \MailerLite_Woo\SebastianBergmann\LinesOfCode\LinesOfCode
    {
        $linesOfCode = \substr_count($source, "\n");
        if ($linesOfCode === 0 && !empty($source)) {
            $linesOfCode = 1;
        }
        try {
            $nodes = $this->parser()->parse($source);
            \assert($nodes !== null);
            return $this->countInAbstractSyntaxTree($linesOfCode, $nodes);
            // @codeCoverageIgnoreStart
        } catch (\MailerLite_Woo\PhpParser\Error $error) {
            throw new \MailerLite_Woo\SebastianBergmann\LinesOfCode\RuntimeException($error->getMessage(), (int) $error->getCode(), $error);
        }
        // @codeCoverageIgnoreEnd
    }
    /**
     * @param Node[] $nodes
     *
     * @throws RuntimeException
     */
    public function countInAbstractSyntaxTree(int $linesOfCode, array $nodes) : \MailerLite_Woo\SebastianBergmann\LinesOfCode\LinesOfCode
    {
        $traverser = new \MailerLite_Woo\PhpParser\NodeTraverser();
        $visitor = new \MailerLite_Woo\SebastianBergmann\LinesOfCode\LineCountingVisitor($linesOfCode);
        $traverser->addVisitor($visitor);
        try {
            /* @noinspection UnusedFunctionResultInspection */
            $traverser->traverse($nodes);
            // @codeCoverageIgnoreStart
        } catch (\MailerLite_Woo\PhpParser\Error $error) {
            throw new \MailerLite_Woo\SebastianBergmann\LinesOfCode\RuntimeException($error->getMessage(), (int) $error->getCode(), $error);
        }
        // @codeCoverageIgnoreEnd
        return $visitor->result();
    }
    private function parser() : \MailerLite_Woo\PhpParser\Parser
    {
        return (new \MailerLite_Woo\PhpParser\ParserFactory())->create(\MailerLite_Woo\PhpParser\ParserFactory::PREFER_PHP7, new \MailerLite_Woo\PhpParser\Lexer());
    }
}
