<?php

declare (strict_types=1);
/*
 * This file is part of sebastian/type.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\SebastianBergmann\Type;

use function assert;
use function class_exists;
use function is_iterable;
use ReflectionClass;
use ReflectionException;
final class IterableType extends \MailerLite_Woo\SebastianBergmann\Type\Type
{
    /**
     * @var bool
     */
    private $allowsNull;
    public function __construct(bool $nullable)
    {
        $this->allowsNull = $nullable;
    }
    /**
     * @throws RuntimeException
     */
    public function isAssignable(\MailerLite_Woo\SebastianBergmann\Type\Type $other) : bool
    {
        if ($this->allowsNull && $other instanceof \MailerLite_Woo\SebastianBergmann\Type\NullType) {
            return \true;
        }
        if ($other instanceof self) {
            return \true;
        }
        if ($other instanceof \MailerLite_Woo\SebastianBergmann\Type\SimpleType) {
            return \is_iterable($other->value());
        }
        if ($other instanceof \MailerLite_Woo\SebastianBergmann\Type\ObjectType) {
            $className = $other->className()->qualifiedName();
            \assert(\class_exists($className));
            try {
                return (new \ReflectionClass($className))->isIterable();
                // @codeCoverageIgnoreStart
            } catch (\ReflectionException $e) {
                throw new \MailerLite_Woo\SebastianBergmann\Type\RuntimeException($e->getMessage(), (int) $e->getCode(), $e);
                // @codeCoverageIgnoreEnd
            }
        }
        return \false;
    }
    public function name() : string
    {
        return 'iterable';
    }
    public function allowsNull() : bool
    {
        return $this->allowsNull;
    }
}
