<?php

declare (strict_types=1);
/*
 * This file is part of sebastian/type.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace MailerLite_Woo\SebastianBergmann\Type;

use function get_class;
use function gettype;
use function strtolower;
abstract class Type
{
    public static function fromValue($value, bool $allowsNull) : self
    {
        $typeName = \gettype($value);
        if ($typeName === 'object') {
            return new \MailerLite_Woo\SebastianBergmann\Type\ObjectType(\MailerLite_Woo\SebastianBergmann\Type\TypeName::fromQualifiedName(\get_class($value)), $allowsNull);
        }
        $type = self::fromName($typeName, $allowsNull);
        if ($type instanceof \MailerLite_Woo\SebastianBergmann\Type\SimpleType) {
            $type = new \MailerLite_Woo\SebastianBergmann\Type\SimpleType($typeName, $allowsNull, $value);
        }
        return $type;
    }
    public static function fromName(string $typeName, bool $allowsNull) : self
    {
        switch (\strtolower($typeName)) {
            case 'callable':
                return new \MailerLite_Woo\SebastianBergmann\Type\CallableType($allowsNull);
            case 'iterable':
                return new \MailerLite_Woo\SebastianBergmann\Type\IterableType($allowsNull);
            case 'null':
                return new \MailerLite_Woo\SebastianBergmann\Type\NullType();
            case 'object':
                return new \MailerLite_Woo\SebastianBergmann\Type\GenericObjectType($allowsNull);
            case 'unknown type':
                return new \MailerLite_Woo\SebastianBergmann\Type\UnknownType();
            case 'void':
                return new \MailerLite_Woo\SebastianBergmann\Type\VoidType();
            case 'array':
            case 'bool':
            case 'boolean':
            case 'double':
            case 'float':
            case 'int':
            case 'integer':
            case 'real':
            case 'resource':
            case 'resource (closed)':
            case 'string':
                return new \MailerLite_Woo\SebastianBergmann\Type\SimpleType($typeName, $allowsNull);
            default:
                return new \MailerLite_Woo\SebastianBergmann\Type\ObjectType(\MailerLite_Woo\SebastianBergmann\Type\TypeName::fromQualifiedName($typeName), $allowsNull);
        }
    }
    public function asString() : string
    {
        return ($this->allowsNull() ? '?' : '') . $this->name();
    }
    /**
     * @deprecated
     *
     * @codeCoverageIgnore
     */
    public function getReturnTypeDeclaration() : string
    {
        return ': ' . $this->asString();
    }
    public abstract function isAssignable(\MailerLite_Woo\SebastianBergmann\Type\Type $other) : bool;
    public abstract function name() : string;
    public abstract function allowsNull() : bool;
}
