<?php

declare (strict_types=1);
namespace MailerLite_Woo\Nyholm\Psr7\Factory;

use MailerLite_Woo\Http\Message\MessageFactory;
use MailerLite_Woo\Http\Message\StreamFactory;
use MailerLite_Woo\Http\Message\UriFactory;
use MailerLite_Woo\Nyholm\Psr7\Request;
use MailerLite_Woo\Nyholm\Psr7\Response;
use MailerLite_Woo\Nyholm\Psr7\Stream;
use MailerLite_Woo\Nyholm\Psr7\Uri;
use MailerLite_Woo\Psr\Http\Message\UriInterface;
/**
 * @author Tobias Nyholm <tobias.nyholm@gmail.com>
 * @author Martijn van der Ven <martijn@vanderven.se>
 *
 * @final This class should never be extended. See https://github.com/Nyholm/psr7/blob/master/doc/final.md
 */
class HttplugFactory implements \MailerLite_Woo\Http\Message\MessageFactory, \MailerLite_Woo\Http\Message\StreamFactory, \MailerLite_Woo\Http\Message\UriFactory
{
    public function createRequest($method, $uri, array $headers = [], $body = null, $protocolVersion = '1.1')
    {
        return new \MailerLite_Woo\Nyholm\Psr7\Request($method, $uri, $headers, $body, $protocolVersion);
    }
    public function createResponse($statusCode = 200, $reasonPhrase = null, array $headers = [], $body = null, $version = '1.1')
    {
        return new \MailerLite_Woo\Nyholm\Psr7\Response((int) $statusCode, $headers, $body, $version, $reasonPhrase);
    }
    public function createStream($body = null)
    {
        return \MailerLite_Woo\Nyholm\Psr7\Stream::create($body ?? '');
    }
    public function createUri($uri = '') : \MailerLite_Woo\Psr\Http\Message\UriInterface
    {
        if ($uri instanceof \MailerLite_Woo\Psr\Http\Message\UriInterface) {
            return $uri;
        }
        return new \MailerLite_Woo\Nyholm\Psr7\Uri($uri);
    }
}
