<?php

declare (strict_types=1);
namespace MailerLite_Woo\Nyholm\Psr7\Factory;

use MailerLite_Woo\Nyholm\Psr7\Request;
use MailerLite_Woo\Nyholm\Psr7\Response;
use MailerLite_Woo\Nyholm\Psr7\ServerRequest;
use MailerLite_Woo\Nyholm\Psr7\Stream;
use MailerLite_Woo\Nyholm\Psr7\UploadedFile;
use MailerLite_Woo\Nyholm\Psr7\Uri;
use MailerLite_Woo\Psr\Http\Message\RequestFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\RequestInterface;
use MailerLite_Woo\Psr\Http\Message\ResponseFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\ResponseInterface;
use MailerLite_Woo\Psr\Http\Message\ServerRequestFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\ServerRequestInterface;
use MailerLite_Woo\Psr\Http\Message\StreamFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\StreamInterface;
use MailerLite_Woo\Psr\Http\Message\UploadedFileFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\UploadedFileInterface;
use MailerLite_Woo\Psr\Http\Message\UriFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\UriInterface;
/**
 * @author Tobias Nyholm <tobias.nyholm@gmail.com>
 * @author Martijn van der Ven <martijn@vanderven.se>
 *
 * @final This class should never be extended. See https://github.com/Nyholm/psr7/blob/master/doc/final.md
 */
class Psr17Factory implements \MailerLite_Woo\Psr\Http\Message\RequestFactoryInterface, \MailerLite_Woo\Psr\Http\Message\ResponseFactoryInterface, \MailerLite_Woo\Psr\Http\Message\ServerRequestFactoryInterface, \MailerLite_Woo\Psr\Http\Message\StreamFactoryInterface, \MailerLite_Woo\Psr\Http\Message\UploadedFileFactoryInterface, \MailerLite_Woo\Psr\Http\Message\UriFactoryInterface
{
    public function createRequest(string $method, $uri) : \MailerLite_Woo\Psr\Http\Message\RequestInterface
    {
        return new \MailerLite_Woo\Nyholm\Psr7\Request($method, $uri);
    }
    public function createResponse(int $code = 200, string $reasonPhrase = '') : \MailerLite_Woo\Psr\Http\Message\ResponseInterface
    {
        if (2 > \func_num_args()) {
            // This will make the Response class to use a custom reasonPhrase
            $reasonPhrase = null;
        }
        return new \MailerLite_Woo\Nyholm\Psr7\Response($code, [], null, '1.1', $reasonPhrase);
    }
    public function createStream(string $content = '') : \MailerLite_Woo\Psr\Http\Message\StreamInterface
    {
        return \MailerLite_Woo\Nyholm\Psr7\Stream::create($content);
    }
    public function createStreamFromFile(string $filename, string $mode = 'r') : \MailerLite_Woo\Psr\Http\Message\StreamInterface
    {
        $resource = @\fopen($filename, $mode);
        if (\false === $resource) {
            if ('' === $mode || \false === \in_array($mode[0], ['r', 'w', 'a', 'x', 'c'])) {
                throw new \InvalidArgumentException('The mode ' . $mode . ' is invalid.');
            }
            throw new \RuntimeException('The file ' . $filename . ' cannot be opened.');
        }
        return \MailerLite_Woo\Nyholm\Psr7\Stream::create($resource);
    }
    public function createStreamFromResource($resource) : \MailerLite_Woo\Psr\Http\Message\StreamInterface
    {
        return \MailerLite_Woo\Nyholm\Psr7\Stream::create($resource);
    }
    public function createUploadedFile(\MailerLite_Woo\Psr\Http\Message\StreamInterface $stream, int $size = null, int $error = \UPLOAD_ERR_OK, string $clientFilename = null, string $clientMediaType = null) : \MailerLite_Woo\Psr\Http\Message\UploadedFileInterface
    {
        if (null === $size) {
            $size = $stream->getSize();
        }
        return new \MailerLite_Woo\Nyholm\Psr7\UploadedFile($stream, $size, $error, $clientFilename, $clientMediaType);
    }
    public function createUri(string $uri = '') : \MailerLite_Woo\Psr\Http\Message\UriInterface
    {
        return new \MailerLite_Woo\Nyholm\Psr7\Uri($uri);
    }
    public function createServerRequest(string $method, $uri, array $serverParams = []) : \MailerLite_Woo\Psr\Http\Message\ServerRequestInterface
    {
        return new \MailerLite_Woo\Nyholm\Psr7\ServerRequest($method, $uri, [], null, '1.1', $serverParams);
    }
}
