<?php

declare (strict_types=1);
namespace MailerLite_Woo\Http\Client\Common;

use MailerLite_Woo\Http\Client\Common\Exception\BatchException;
use MailerLite_Woo\Psr\Http\Client\ClientExceptionInterface;
use MailerLite_Woo\Psr\Http\Client\ClientInterface;
final class BatchClient implements \MailerLite_Woo\Http\Client\Common\BatchClientInterface
{
    /**
     * @var ClientInterface
     */
    private $client;
    public function __construct(\MailerLite_Woo\Psr\Http\Client\ClientInterface $client)
    {
        $this->client = $client;
    }
    public function sendRequests(array $requests) : \MailerLite_Woo\Http\Client\Common\BatchResult
    {
        $batchResult = new \MailerLite_Woo\Http\Client\Common\BatchResult();
        foreach ($requests as $request) {
            try {
                $response = $this->client->sendRequest($request);
                $batchResult = $batchResult->addResponse($request, $response);
            } catch (\MailerLite_Woo\Psr\Http\Client\ClientExceptionInterface $e) {
                $batchResult = $batchResult->addException($request, $e);
            }
        }
        if ($batchResult->hasExceptions()) {
            throw new \MailerLite_Woo\Http\Client\Common\Exception\BatchException($batchResult);
        }
        return $batchResult;
    }
}
