<?php

namespace MailerLite_Woo\Http\Discovery;

use MailerLite_Woo\Http\Discovery\Exception\DiscoveryFailedException;
use MailerLite_Woo\Psr\Http\Message\RequestFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\ResponseFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\ServerRequestFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\StreamFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\UploadedFileFactoryInterface;
use MailerLite_Woo\Psr\Http\Message\UriFactoryInterface;
/**
 * Finds PSR-17 factories.
 *
 * @author Tobias Nyholm <tobias.nyholm@gmail.com>
 */
final class Psr17FactoryDiscovery extends \MailerLite_Woo\Http\Discovery\ClassDiscovery
{
    private static function createException($type, \MailerLite_Woo\Http\Discovery\Exception $e)
    {
        return new \MailerLite_Woo\Http\Discovery\Exception\NotFoundException('No PSR-17 ' . $type . ' found. Install a package from this list: https://packagist.org/providers/psr/http-factory-implementation', 0, $e);
    }
    /**
     * @return RequestFactoryInterface
     *
     * @throws Exception\NotFoundException
     */
    public static function findRequestFactory()
    {
        try {
            $messageFactory = static::findOneByType(\MailerLite_Woo\Psr\Http\Message\RequestFactoryInterface::class);
        } catch (\MailerLite_Woo\Http\Discovery\Exception\DiscoveryFailedException $e) {
            throw self::createException('request factory', $e);
        }
        return static::instantiateClass($messageFactory);
    }
    /**
     * @return ResponseFactoryInterface
     *
     * @throws Exception\NotFoundException
     */
    public static function findResponseFactory()
    {
        try {
            $messageFactory = static::findOneByType(\MailerLite_Woo\Psr\Http\Message\ResponseFactoryInterface::class);
        } catch (\MailerLite_Woo\Http\Discovery\Exception\DiscoveryFailedException $e) {
            throw self::createException('response factory', $e);
        }
        return static::instantiateClass($messageFactory);
    }
    /**
     * @return ServerRequestFactoryInterface
     *
     * @throws Exception\NotFoundException
     */
    public static function findServerRequestFactory()
    {
        try {
            $messageFactory = static::findOneByType(\MailerLite_Woo\Psr\Http\Message\ServerRequestFactoryInterface::class);
        } catch (\MailerLite_Woo\Http\Discovery\Exception\DiscoveryFailedException $e) {
            throw self::createException('server request factory', $e);
        }
        return static::instantiateClass($messageFactory);
    }
    /**
     * @return StreamFactoryInterface
     *
     * @throws Exception\NotFoundException
     */
    public static function findStreamFactory()
    {
        try {
            $messageFactory = static::findOneByType(\MailerLite_Woo\Psr\Http\Message\StreamFactoryInterface::class);
        } catch (\MailerLite_Woo\Http\Discovery\Exception\DiscoveryFailedException $e) {
            throw self::createException('stream factory', $e);
        }
        return static::instantiateClass($messageFactory);
    }
    /**
     * @return UploadedFileFactoryInterface
     *
     * @throws Exception\NotFoundException
     */
    public static function findUploadedFileFactory()
    {
        try {
            $messageFactory = static::findOneByType(\MailerLite_Woo\Psr\Http\Message\UploadedFileFactoryInterface::class);
        } catch (\MailerLite_Woo\Http\Discovery\Exception\DiscoveryFailedException $e) {
            throw self::createException('uploaded file factory', $e);
        }
        return static::instantiateClass($messageFactory);
    }
    /**
     * @return UriFactoryInterface
     *
     * @throws Exception\NotFoundException
     */
    public static function findUriFactory()
    {
        try {
            $messageFactory = static::findOneByType(\MailerLite_Woo\Psr\Http\Message\UriFactoryInterface::class);
        } catch (\MailerLite_Woo\Http\Discovery\Exception\DiscoveryFailedException $e) {
            throw self::createException('url factory', $e);
        }
        return static::instantiateClass($messageFactory);
    }
    /**
     * @return UriFactoryInterface
     *
     * @throws Exception\NotFoundException
     *
     * @deprecated This will be removed in 2.0. Consider using the findUriFactory() method.
     */
    public static function findUrlFactory()
    {
        return static::findUriFactory();
    }
}
