<?php

declare (strict_types=1);
namespace MailerLite_Woo\Http\Adapter\Guzzle7;

use MailerLite_Woo\GuzzleHttp\Client as GuzzleClient;
use MailerLite_Woo\GuzzleHttp\ClientInterface;
use MailerLite_Woo\GuzzleHttp\HandlerStack;
use MailerLite_Woo\GuzzleHttp\Middleware;
use MailerLite_Woo\GuzzleHttp\Utils;
use MailerLite_Woo\Http\Client\HttpAsyncClient;
use MailerLite_Woo\Http\Client\HttpClient;
use MailerLite_Woo\Psr\Http\Message\RequestInterface;
use MailerLite_Woo\Psr\Http\Message\ResponseInterface;
/**
 * HTTP Adapter for Guzzle 7.
 *
 * @author Tobias Nyholm <tobias.nyholm@gmail.com>
 */
final class Client implements \MailerLite_Woo\Http\Client\HttpClient, \MailerLite_Woo\Http\Client\HttpAsyncClient
{
    /**
     * @var ClientInterface
     */
    private $guzzle;
    public function __construct(?\MailerLite_Woo\GuzzleHttp\ClientInterface $guzzle = null)
    {
        if (!$guzzle) {
            $guzzle = self::buildClient();
        }
        $this->guzzle = $guzzle;
    }
    /**
     * Factory method to create the Guzzle 7 adapter with custom Guzzle configuration.
     */
    public static function createWithConfig(array $config) : \MailerLite_Woo\Http\Adapter\Guzzle7\Client
    {
        return new self(self::buildClient($config));
    }
    /**
     * {@inheritdoc}
     */
    public function sendRequest(\MailerLite_Woo\Psr\Http\Message\RequestInterface $request) : \MailerLite_Woo\Psr\Http\Message\ResponseInterface
    {
        return $this->sendAsyncRequest($request)->wait();
    }
    /**
     * {@inheritdoc}
     */
    public function sendAsyncRequest(\MailerLite_Woo\Psr\Http\Message\RequestInterface $request)
    {
        $promise = $this->guzzle->sendAsync($request);
        return new \MailerLite_Woo\Http\Adapter\Guzzle7\Promise($promise, $request);
    }
    /**
     * Build the Guzzle client instance.
     */
    private static function buildClient(array $config = []) : \MailerLite_Woo\GuzzleHttp\Client
    {
        $handlerStack = new \MailerLite_Woo\GuzzleHttp\HandlerStack(\MailerLite_Woo\GuzzleHttp\Utils::chooseHandler());
        $handlerStack->push(\MailerLite_Woo\GuzzleHttp\Middleware::prepareBody(), 'prepare_body');
        $config = \array_merge(['handler' => $handlerStack], $config);
        return new \MailerLite_Woo\GuzzleHttp\Client($config);
    }
}
